OC.L10N.register(
    "spreed",
    {
    "a conversation" : "een gesprek",
    "(Duration %s)" : "(Duur %s)",
    "You attended a call with {user1}" : "Je nam deel aan een oproep met {user1}",
    "_%n guest_::_%n guests_" : ["%n gast","%n gasten"],
    "You attended a call with {user1} and {user2}" : "Je nam deel aan een oproep met {user1} and {user2}",
    "You attended a call with {user1}, {user2} and {user3}" : "Je nam deel aan een oproep met {user1}, {user2} and {user3}",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "Je nam deel aan een oproep met {user1}, {user2}, {user3} and {user4}",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "Je nam deel aan een oproep met {user1}, {user2}, {user3}, {user4} and {user5}",
    "_%n other_::_%n others_" : ["%n andere","%n anderen"],
    "{actor} invited you to {call}" : "{actor} heeft je uitgenodigd voor telefoongesprek {call}",
    "You were invited to a <strong>conversation</strong> or had a <strong>call</strong>" : "Je bent uitgenodigd voor een <strong>gesprek</strong> of had een <strong>oproep</strong>",
    "Other activities" : "Andere activiteiten",
    "Talk" : "Talk",
    "Guest" : "Gast",
    "## Welcome to Nextcloud Talk!\nIn this conversation you will be informed about new features available in Nextcloud Talk." : "Welkom bij Nextcloud Talk!\nIn dit gesprek vertellen we je over de nieuwe functies die beschikbaar zijn in Nextcloud Talk.",
    "## New in Talk %s" : "## Nieuw in Talk %s",
    "- Microsoft Edge and Safari can now be used to participate in audio and video calls" : "- Microsoft Edge en Safari kunnen nu worden gebruikt om deel te nemen aan audio- en videogesprekken",
    "- One-to-one conversations are now persistent and cannot be turned into group conversations by accident anymore. Also when one of the participants leaves the conversation, the conversation is not automatically deleted anymore. Only if both participants leave, the conversation is deleted from the server" : "- een-op-eengesprekken zijn nu blijvend en kunnen niet meer per ongeluk in groepsgesprekken worden veranderd. Wanneer een deelnemer het gesprek verlaat, wordt het gesprek daarnaast niet meer automatisch verwijderd. Alleen als beide deelnemers vertrekken, wordt het gesprek van de server verwijderd.",
    "- You can now notify all participants by posting \"@all\" into the chat" : "- Je kunt nu alle deelnemers op de hoogte stellen door \"@all\" in de chat te plaatsen",
    "- With the \"arrow-up\" key you can repost your last message" : "- Met de \"pijl-omhoog\"-toets kun je je laatste bericht opnieuw plaatsen",
    "- Talk can now have commands, send \"/help\" as a chat message to see if your administrator configured some" : "- Talk heeft nu ook commando's: stuur \"/help\" als chatbericht om te zien of er commando's door de beheerder zijn ingesteld",
    "- With projects you can create quick links between conversations, files and other items" : "- Met projecten kun je snel links maken tussen gesprekken, bestanden en andere objecten",
    "- You can now mention guests in the chat" : "- Je kunt nu gasten in de chat vernoemen met een mention",
    "- Conversations can now have a lobby. This will allow moderators to join the chat and call already to prepare the meeting, while users and guests have to wait" : "- Gesprekken kunnen nu een lobby hebben. Dit stelt moderators in staat om alvast deel te nemen aan de chat en het gesprek om de vergadering voor te bereiden, terwijl gebruikers en gasten moeten wachten",
    "- You can now directly reply to messages giving the other users more context what your message is about" : "- Je kunt nu direct op berichten reageren, zodat je andere gebruikers meer context kunt geven over de inhoud van je bericht",
    "- Searching for conversations and participants will now also filter your existing conversations, making it much easier to find previous conversations" : "- Zoeken naar gesprekken en deelnemers filtert nu ook je bestaande gesprekken, waardoor het veel gemakkelijker wordt om eerdere gesprekken te vinden",
    "- You can now add custom user groups to conversations when the circles app is installed" : "- Je kunt nu aangepaste gebruikersgroepen toevoegen aan gesprekken wanneer de kringen-app is geïnstalleerd",
    "- Check out the new grid and call view" : "- Een nieuw raster- en oproepoverzicht",
    "- You can now upload and drag'n'drop files directly from your device into the chat" : "- Je kunt bestanden nu rechtstreeks vanaf je apparaat naar de chat uploaden en slepen",
    "- Shared files are now opened directly inside the chat view with the viewer apps" : "- Gedeelde bestanden worden nu direct geopend in het chatvenster met de viewer-apps",
    "- You can now search for chats and messages in the unified search in the top bar" : "- Je kunt nu naar chats en berichten zoeken via de geïntegreerde zoekfunctie in de bovenste balk",
    "- Spice up your messages with emojis from the emoji picker" : "- Geef je berichten meer pit met emoji's uit de emoji-kiezer",
    "- You can now change your camera and microphone while being in a call" : "- Je kunt nu je camera en microfoon wijzigen tijdens een telefoongesprek",
    "- Give your conversations some context with a description and open it up so logged in users can find it and join themselves" : "- Geef je gesprekken wat context met een beschrijving en open ze zodat ingelogde gebruikers ze kunnen vinden en zelf kunnen deelnemen",
    "- See a read status and send failed messages again" : "- Zie een leesstatus en verzend mislukte berichten opnieuw",
    "- Raise your hand in a call with the R key" : "- Steek tijdens een telefoongesprek je hand op met de R-toets",
    "- Join the same conversation and call from multiple devices" : "- Neem deel aan en bel in hetzelfde gesprek vanaf meerdere apparaten",
    "- Send voice messages, share your location or contact details" : "- Verstuur gesproken berichten, deel jou locatie of contact informatie",
    "- Add groups to a conversation and new group members will automatically be added as participants" : "- Voeg groepen toe aan een gesprek en nieuwe groepsleden worden automatisch toegevoegd als deelnemers",
    "- A preview of your audio and video is shown before joining a call" : "- Een preview van je audio en video wordt getoond voor het deelnemen aan een gesprek",
    "- You can now blur your background in the newly designed call view" : "- Je kunt nu je achtergrond vervagen in het nieuw ontworpen gespreksoverzicht",
    "- Moderators can now assign general and individual permissions to participants" : "- Moderatoren kunnen nu algemene en individuele machtigingen aan deelnemers toekennen",
    "- You can now react to chat messages" : "- Je kunt nu reageren op chat berichten",
    "- In the sidebar you can now find an overview of the latest shared items" : "- In de zijbalk kun je nu een overzicht vinden van de laatst gedeelde objecten",
    "- Use a poll to collect the opinions of others or settle on a date" : "- Bevraag de mening van anderen of gebruik een peiling om een datum te kiezen",
    "- Configure an expiration time for chat messages" : "- Een vervaltijd voor chatberichten configureren",
    "- Start calls without notifying others in big conversations. You can send individual call notifications once the call has started." : "- Start gesprekken zonder anderen op de hoogte te stellen in grote gesprekken. U kunt individuele gespreksmeldingen sturen zodra het gesprek is gestart.",
    "- Send chat messages without notifying the recipients in case it is not urgent" : "- Chatberichten verzenden zonder de ontvangers hiervan op de hoogte te stellen voor gevallen dat het bericht niet dringend is",
    "- Emojis can now be autocompleted by typing a \":\"" : "- Emoji's kunnen nu automatisch worden aangevuld door een \":\" te typen",
    "- Link various items using the new smart-picker by typing a \"/\"" : "- Koppel verschillende items met behulp van de nieuwe Smart Picker door een \"/\" te typen",
    "- Moderators can now create breakout rooms (requires the High-performance backend)" : "- Moderators kunnen nu breakout rooms creëeren (High-performance backend is noodzakelijk)",
    "- Messages can now be edited by logged-in authors and moderators for 6 hours" : "- Berichten kunnen nu worden aangepast door ingelogde auteurs en moderators tot maximaal 6 uur.",
    "- Moderators can now ban accounts and guests to prevent them from rejoining a conversation" : "- Moderators kunnen nu accounts en gasten verbannen om te voorkomen dat ze terug komen in een gesprek.",
    "- Schedule a meeting into your calendar from within a conversation" : "- Plan een vergadering in je eigen agenda vanuit het gesprek",
    "- Moderators can now pin messages so they are kept at the top" : "- Moderators kunnen nu berichten vastzetten zodat ze bovenaan blijven staan.",
    "_All %n participant_::_All %n participants_" : ["%n deelnemer","Alle %n deelenemers"],
    "Talk updates ✅" : "Talk updates ✅",
    "Reaction deleted by author" : "Reactie verwijderd door schrijver",
    "{actor} created the conversation" : "{actor} heeft het gesprek gemaakt",
    "You created the conversation" : "Je hebt het gesprek gemaakt",
    "System created the conversation" : "System heeft het gesprek aangemaakt",
    "An administrator created the conversation" : "Een beheerder heeft het gesprek gemaakt",
    "{actor} renamed the conversation from \"%1$s\" to \"%2$s\"" : "{actor} hernoemde gesprek van  \"%1$s\" naar \"%2$s\"",
    "You renamed the conversation from \"%1$s\" to \"%2$s\"" : "Je hernoemde het gesprek van \"%1$s\" naar \"%2$s\"",
    "An administrator renamed the conversation from \"%1$s\" to \"%2$s\"" : "Een beheerder hernoemde het gesprek van  \"%1$s\" naar \"%2$s\"",
    "{actor} set the description" : "{actor} de beschrijving ingesteld",
    "You set the description" : "Jij hebt de beschrijving ingesteld",
    "An administrator set the description" : "Een beheerder heeft de beschrijving ingesteld",
    "{actor} removed the description" : "{actor} verwijderde de beschrijving",
    "You removed the description" : "Jij verwijderde de beschrijving",
    "An administrator removed the description" : "Een beheerder verwijderde de beschrijving",
    "You started a silent call" : "Je startte een stille oproep",
    "{actor} started a silent call" : "{actor} startte een stille oproep",
    "You started a call" : "Je startte een telefoongesprek",
    "{actor} started a call" : "{actor} startte een telefoongesprek",
    "Incoming call" : "Inkomend gesprek",
    "{actor} joined the call" : "{actor} heeft zich bij het telefoongesprek aangesloten",
    "You joined the call" : "Je hebt je bij de oproep aangesloten",
    "{actor} left the call" : "{actor} heeft de oproep verlaten",
    "You left the call" : "Je hebt het telefoongesprek verlaten",
    "{actor} unlocked the conversation" : "{actor} heeft het gesprek ontgrendeld",
    "You unlocked the conversation" : "Je hebt het gesprek ontgrendeld.",
    "An administrator unlocked the conversation" : "Een beheerder heeft het gesprek ontgrendeld",
    "{actor} locked the conversation" : "{actor} heeft het gesprek vergrendeld",
    "You locked the conversation" : "Je hebt het gesprek vergrendeld",
    "An administrator locked the conversation" : "Een beheerder heeft het gesprek vergrendeld",
    "{actor} limited the conversation to the current participants" : "{actor} heeft het gesprek beperkt tot de huidige deelnemers",
    "You limited the conversation to the current participants" : "Je hebt het gesprek beperkt tot de huidige deelnemers",
    "An administrator limited the conversation to the current participants" : "Een beheerder heeft het gesprek beperkt tot de huidige deelnemers",
    "{actor} opened the conversation to registered users" : "{actor} heeft het gesprek geopend voor geregistreerde gebruikers",
    "You opened the conversation to registered users" : "Je hebt het gesprek geopend voor geregistreerde gebruikers",
    "An administrator opened the conversation to registered users" : "Een beheerder heeft het gesprek geopend voor geregistreerde gebruikers",
    "{actor} opened the conversation to registered users and users created with the Guests app" : "{actor} heeft het gesprek geopend voor geregistreerde gebruikers en voor gebruikers gemaakt in de Gasten app",
    "You opened the conversation to registered users and users created with the Guests app" : "Je hebt het gesprek geopend voor geregistreerde gebruikers en voor gebruikers gemaakt in de Gasten app",
    "An administrator opened the conversation to registered users and users created with the Guests app" : "Een beheerder heeft het gesprek geopend voor geregistreerde gebruikers en voor gebruikers gemaakt in de Gasten app",
    "The conversation is now open to everyone" : "Het gesprek is nu open voor iedereen",
    "{actor} opened the conversation to everyone" : "{actor} heeft het gesprek voor iedereen geopend",
    "You opened the conversation to everyone" : "Je hebt het gesprek voor iedereen geopend",
    "{actor} restricted the conversation to moderators" : "{actor} beperkte het gesprek tot moderators",
    "You restricted the conversation to moderators" : "Je hebt het gesprek beperkt tot moderators",
    "{actor} started breakout rooms" : "{actor} startte aparte vergaderruimtes",
    "You started breakout rooms" : "Je startte aparte vergaderruimtes",
    "{actor} stopped breakout rooms" : "{actor} beëindigde aparte vergaderruimtes",
    "You stopped breakout rooms" : "Je beëindigde aparte vergaderruimtes",
    "{actor} allowed guests" : "{actor} heeft gasten toegelaten",
    "You allowed guests" : "Je hebt gasten toegelaten",
    "An administrator allowed guests" : "Een beheerder heeft gasten toegelaten",
    "{actor} disallowed guests" : "{actor} heeft gasten geweigerd",
    "You disallowed guests" : "Je hebt gasten geweigerd",
    "An administrator disallowed guests" : "Een beheerder heeft gasten geweigerd",
    "{actor} set a password" : "{actor} heeft een wachtwoord ingesteld",
    "You set a password" : "Je hebt een wachtwoord ingesteld",
    "An administrator set a password" : "Een beheerder heeft een wachtwoord ingesteld",
    "{actor} removed the password" : "{actor} heeft het wachtwoord verwijderd",
    "You removed the password" : "Je hebt het wachtwoord verwijderd",
    "An administrator removed the password" : "Een beheerder heeft het wachtwoord verwijderd",
    "{actor} added {user}" : "{actor} heeft {user} toegevoegd",
    "You joined the conversation" : "Je neemt deel aan het gesprek",
    "{actor} joined the conversation" : "{actor} neemt deel aan het gesprek",
    "You added {user}" : "Je hebt {user} toegevoegd",
    "{actor} added you" : "{actor} heeft jou toegevoegd",
    "An administrator added you" : "Een beheerder heeft jou toegevoegd",
    "An administrator added {user}" : "Een beheerder heeft {user} toegevoegd",
    "You left the conversation" : "Je hebt het gesprek verlaten",
    "{actor} left the conversation" : "{actor} heeft het gesprek verlaten",
    "{actor} removed {user}" : "{actor} heeft {user} verwijderd",
    "You removed {user}" : "Je hebt {user} verwijderd",
    "{actor} removed you" : "{actor} heeft jou verwijderd",
    "An administrator removed you" : "Een beheerder heeft jou verwijderd",
    "An administrator removed {user}" : "Een beheerder heeft {user} verwijderd",
    "{actor} invited {federated_user}" : "{actor} nodigde {federated_user} uit",
    "You invited {federated_user}" : "Je nodigde {federated_user} uit",
    "You accepted the invitation" : "Je hebt de uitnodiging geaccepteerd",
    "{actor} invited you" : "{actor} heeft je uitgenodigd",
    "An administrator invited you" : "Een beheerder heeft je uitgenodigd",
    "An administrator invited {federated_user}" : "Een beheerder heeft {federated_user} uitgenodigd",
    "{federated_user} accepted the invitation" : "{federated_user} heeft de uitnodiging geaccepteerd",
    "{actor} removed {federated_user}" : "{actor} heeft {federated_user} verwijderd",
    "You removed {federated_user}" : "Jij hebt {federated_user} verwijderd",
    "You declined the invitation" : "Je hebt de uitnodiging afgewezen",
    "An administrator removed {federated_user}" : "Een beheerder heeft {federated_user} verwijderd",
    "{federated_user} declined the invitation" : "{federated_user} heeft de uitnodiging geweigerd",
    "{actor} added group {group}" : "{actor} voegde groep {group} toe",
    "You added group {group}" : "Je voegde groep {group} toe",
    "An administrator added group {group}" : "Een beheerder voegde groep {group} toe",
    "{actor} removed group {group}" : "{actor} verwijderde groep {group}",
    "You removed group {group}" : "Je verwijderde groep  {group}",
    "An administrator removed group {group}" : "Een beheerder verwijderde groep {group}",
    "{actor} added team {circle}" : "{actor} voegde team {circle} toe",
    "You added team {circle}" : "Je voegde team {circle} toe",
    "An administrator added team {circle}" : "Een beheerder voegde team {circle}  toe",
    "{actor} removed team {circle}" : "{actor} verwijderde team {circle}",
    "You removed team {circle}" : "Je verwijderde team {circle}",
    "An administrator removed team {circle}" : "Een beheerder heeft team {circle} verwijderd",
    "{actor} added {phone}" : "{actor} voegde {phone} toe",
    "You added {phone}" : "Je voegde {phone} toe.",
    "An administrator added {phone}" : "Een beheerder heeft {phone} toegevoegd",
    "{actor} removed {phone}" : "{actor} verwijderde {phone}",
    "You removed {phone}" : "Je verwijderde {phone}",
    "An administrator removed {phone}" : "Een beheerder heeft {phone} verwijderd",
    "{actor} promoted {user} to moderator" : "{actor} heeft {user} bevorderd tot moderator",
    "You promoted {user} to moderator" : "Je hebt {user} bevorderd tot moderator",
    "{actor} promoted you to moderator" : "{actor} heeft jou tot moderator bevorderd",
    "An administrator promoted you to moderator" : "Een beheerder heeft jou tot moderator bevorderd",
    "An administrator promoted {user} to moderator" : "Een beheerder heeft {user} tot moderator bevorderd",
    "{actor} demoted {user} from moderator" : "{actor} heeft {user} gedegradeerd als moderator",
    "You demoted {user} from moderator" : "Je hebt {user} gedegradeerd als moderator",
    "{actor} demoted you from moderator" : "{actor} heeft jou uit gedegradeerd als moderator",
    "An administrator demoted you from moderator" : "Een beheerder heeft jou gedegradeerd als moderator",
    "An administrator demoted {user} from moderator" : "Een beheerder heeft {user} gedegradeerd als moderator",
    "{actor} shared a file which is no longer available" : "{actor} heeft een bestand gedeeld dat niet meer beschikbaar is",
    "You shared a file which is no longer available" : "Je hebt een bestand gedeeld dat niet meer beschikbaar is",
    "File shares are currently not supported in federated conversations" : "Bestandsdelen is momenteel niet ondersteund in gesprekken met andere Nextcloud servers",
    "The shared location is malformed" : "De gedeelde locatie heeft een onjuiste opgemaakt",
    "{actor} set up Matterbridge to synchronize this conversation with other chats" : "{actor} heeft Matterbridge opgezet om dit gesprek te synchroniseren met andere chats",
    "You set up Matterbridge to synchronize this conversation with other chats" : "Je hebt Matterbridge opgezet om dit gesprek te synchroniseren met andere chats.",
    "{actor} updated the Matterbridge configuration" : "{actor} heeft de Matterbridge-configuratie aangepast",
    "You updated the Matterbridge configuration" : "Je hebt de Matterbridge-configuratie aangepast",
    "{actor} removed the Matterbridge configuration" : "{actor} heeft de Matterbridge-configuratie verwijderd",
    "You removed the Matterbridge configuration" : "Je hebt de Matterbridge-configuratie verwijderd",
    "{actor} started Matterbridge" : "{actor} heeft Matterbridge gestart",
    "You started Matterbridge" : "Je hebt Matterbridge gestart",
    "{actor} stopped Matterbridge" : "{actor} heeft Matterbridge gestopt",
    "You stopped Matterbridge" : "Je hebt Matterbridge gestopt",
    "{actor} deleted a message" : "{actor} verwijderde een bericht",
    "You deleted a message" : "Je verwijderde een bericht",
    "{actor} edited a message" : "{actor} bewerkte een bericht",
    "You edited a message" : "Je bewerkte een bericht",
    "{actor} deleted a reaction" : "{actor} verwijderde een bericht.",
    "You deleted a reaction" : "Je verwijderde een bericht",
    "_You set the message expiration to %n week_::_You set the message expiration to %n weeks_" : ["Je hebt de vervalperiode voor berichten ingesteld op %n week","Je hebt de vervalperiode voor berichten ingesteld op %n weken"],
    "_You set the message expiration to %n day_::_You set the message expiration to %n days_" : ["Je hebt de vervalperiode voor berichten ingesteld op %n dag","Je hebt de vervalperiode voor berichten ingesteld op %n dagen"],
    "_You set the message expiration to %n hour_::_You set the message expiration to %n hours_" : ["Je hebt de vervalperiode voor berichten ingesteld op %n uur","Je hebt de vervalperiode voor berichten ingesteld op %n uren"],
    "_You set the message expiration to %n minute_::_You set the message expiration to %n minutes_" : ["Je hebt de vervalperiode voor berichten ingesteld op %n minuut","Je hebt de vervalperiode voor berichten ingesteld op %n minuten"],
    "_{actor} set the message expiration to %n week_::_{actor} set the message expiration to %n weeks_" : ["{actor} heeft de vervalperiode voor berichten ingesteld op %n week","{actor} heeft de vervalperiode voor berichten ingesteld op %n weken"],
    "_{actor} set the message expiration to %n day_::_{actor} set the message expiration to %n days_" : ["{actor} heeft de vervalperiode voor berichten ingesteld op %n dag","{actor} heeft de vervalperiode voor berichten ingesteld op %n dagen"],
    "_{actor} set the message expiration to %n hour_::_{actor} set the message expiration to %n hours_" : ["{actor} heeft de vervalperiode voor berichten ingesteld op %n uur","{actor} heeft de vervalperiode voor berichten ingesteld op %n uren"],
    "_{actor} set the message expiration to %n minute_::_{actor} set the message expiration to %n minutes_" : ["{actor} heeft de vervalperiode voor berichten ingesteld op %n minuut","{actor} heeft de vervalperiode voor berichten ingesteld op %n minuten"],
    "{actor} disabled message expiration" : "{actor} heeft berichtverval uitgeschakeld",
    "You disabled message expiration" : "Jij hebt berichtverval uitgeschakeld",
    "{actor} cleared the history of the conversation" : "{actor} heeft de gesprekshistorie leeggemaakt",
    "You cleared the history of the conversation" : "Je hebt de gesprekshistorie schoongemaakt",
    "{actor} set the conversation picture" : "{actor} heeft de gespreksafbeelding ingesteld",
    "You set the conversation picture" : "Jij hebt de gespreksafbeelding ingesteld",
    "{actor} removed the conversation picture" : "{actor} heeft de gespreksafbeelding verwijderd",
    "You removed the conversation picture" : "Jij hebt de gespreksafbeelding verwijderd",
    "{actor} ended the poll {poll}" : "{actor} beëindigde de peiling {poll}",
    "You ended the poll {poll}" : "Je beëindigde de peiling {poll}",
    "{actor} started the video recording" : "{actor} startte de video-opname",
    "You started the video recording" : "Jij startte de video-opname",
    "{actor} stopped the video recording" : "{actor} beëindigde de video-opname",
    "You stopped the video recording" : "Jij beëindigde de video-opname",
    "{actor} started the audio recording" : "{actor} startte de audio-opname",
    "You started the audio recording" : "Jij startte de audio-opname",
    "{actor} stopped the audio recording" : "{actor} beëindigde de audio-opname",
    "You stopped the audio recording" : "Jij beëindigde de audio-opname",
    "The recording failed" : "De opname is mislukt",
    "Someone voted on the poll {poll}" : "Iemand heeft gestemd op de enquête {poll}",
    "Message deleted by author" : "Bericht verwijderd door de schrijver",
    "Message deleted by {actor}" : "Bericht verwijderd door {actor}",
    "Message deleted by you" : "Bericht verwijderd door jou",
    "Deleted user" : "Verwijderen gebruiker",
    "Unknown number" : "Onbekend aantal",
    "Administration" : "Beheer",
    "System" : "Systeem",
    "%s (guest)" : "%s (gast)",
    "Call ended (Duration {duration})" : "Gesprek beëindigd (duur {duration})",
    "Call was ended, as it reached the maximum call duration (Duration {duration})" : "Gesprek is beëindigd, omdat het de maximale gespreksduur heeft bereikt (duur {duration})",
    "{actor} ended the call (Duration {duration})" : "{actor} beëindigde het gesprek (duur {duration})",
    "_Call with %n guest was ended, as it reached the maximum call duration (Duration {duration})_::_Call with %n guests was ended, as it reached the maximum call duration (Duration {duration})_" : ["Gesprek met %n gast is beëindigd, omdat het de maximale gespreksduur heeft bereikt (duur {duration})","Gesprek met %n gasten is beëindigd, omdat het de maximale gespreksduur heeft bereikt (duur {duration})"],
    "_Call with %n guest ended (Duration {duration})_::_Call with %n guests ended (Duration {duration})_" : ["Gesprek met %n gast is beëindigd (duur {duration})","Oproep met%n gasten is beëindigd (duur {duration})"],
    "_{actor} ended the call with %n guest (Duration {duration})_::_{actor} ended the call with %n guests (Duration {duration})_" : ["{actor} beëindigde het gesprek met %n gasten (Duration {duration})","{actor} beëindigde het gesprek met %n gasten (Looptijd {duration})"],
    "Call with {user1} was ended, as it reached the maximum call duration (Duration {duration})" : "Gesprek met {user1} is beëindigd, omdat het de maximale gespreksduur heeft bereikt (duur {duration})",
    "Call with {user1} ended (Duration {duration})" : "Gesprek met {user1} is beëindigd (duur {duration})",
    "{actor} ended the call with {user1} (Duration {duration})" : "{actor} beëindigde het gesprek met {user1} (Looptijd {duration})",
    "Call with {user1} and {user2} was ended, as it reached the maximum call duration (Duration {duration})" : "Gesprek met {user1} en {user2} is beëindigd, omdat het de maximale gespreksduur heeft bereikt (duur {duration})",
    "Call with {user1} and {user2} ended (Duration {duration})" : "Gesprek met {user1} en {user2} is beëindigd (duur {duration})",
    "{actor} ended the call with {user1} and {user2} (Duration {duration})" : "{actor} beëindigde het gesprek met {user1} en {user2} (Looptijd {duration})",
    "Call with {user1}, {user2} and {user3} was ended, as it reached the maximum call duration (Duration {duration})" : "Gesprek met {user1}, {user2} en {user3} is beëindigd, omdat het de maximale gespreksduur heeft bereikt (duur {duration})",
    "Call with {user1}, {user2} and {user3} ended (Duration {duration})" : "Gesprek met {user1}, {user2} en {user3} is beëindigd (duur {duration})",
    "{actor} ended the call with {user1}, {user2} and {user3} (Duration {duration})" : "{actor} beëindigde het gesprek met {user1}, {user2} en {user3} (Looptijd {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} was ended, as it reached the maximum call duration (Duration {duration})" : "Gesprek met {user1}, {user2}, {user3} en {user4} is beëindigd, omdat het de maximale gespreksduur heeft bereikt (duur {duration})",
    "Call with {user1}, {user2}, {user3} and {user4} ended (Duration {duration})" : "Gesprek met {user1}, {user2}, {user3} en {user4} is beëindigd (duur {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3} and {user4} (Duration {duration})" : "{actor} beëindigde het gesprek met {user1}, {user2}, {user3} en {user4} (Looptijd {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} was ended, as it reached the maximum call duration (Duration {duration})" : "Gesprek met {user1}, {user2}, {user3}, {user4} en {user5}is beëindigd, omdat het de maximale gespreksduur heeft bereikt (duur {duration})",
    "Call with {user1}, {user2}, {user3}, {user4} and {user5} ended (Duration {duration})" : "Gesprek met {user1}, {user2}, {user3}, {user4} en {user5} is beëindigd (duur {duration})",
    "{actor} ended the call with {user1}, {user2}, {user3}, {user4} and {user5} (Duration {duration})" : "{actor} beëindigde het gesprek met {user1}, {user2}, {user3}, {user4} en {user5} (Looptijd {duration})",
    "Message of {user} in {conversation}" : "Bericht van {user} in {conversation}",
    "Message of {user}" : "Bericht van {user}",
    "Message of a deleted user in {conversation}" : "Bericht van een verwijderde gebruiker in {conversation}",
    "Talk conversations" : "Talk gesprekken",
    "Talk to %s" : "Spreek met %s",
    "An error occurred. Please contact your administrator." : "Er is een fout opgetreden. Neem contact op met de beheerder a.u.b.",
    "Storage quota exceeded" : "Opslagquotum overschreden",
    "File not found" : "Bestand niet gevonden",
    "File is not shared, or shared but not with the user" : "Bestand is niet gedeeld, of wel gedeeld maar niet met de gebruiker",
    "No account available to delete." : "Geen account beschikbaar om te verwijderen.",
    "Poll" : "Peiling",
    "Password needs to be set" : "Wachtwoord moet ingesteld worden",
    "Uploading the file failed" : "Uploaden bestand mislukt",
    "No image file provided" : "Geen afbeelding opgegeven",
    "File is too big" : "Bestand te groot",
    "Invalid file provided" : "Ongeldig bestand aangeleverd",
    "Invalid image" : "Ongeldige afbeelding",
    "Unknown filetype" : "Onbekend bestandsformaat",
    "Talk mentions" : "Talk vermeldingen",
    "More conversations" : "Meer gesprekken",
    "Say hi to your friends and colleagues!" : "Zeg hallo tegen je vrienden en collega's!",
    "No unread mentions" : "Geen ongelezen vermeldingen",
    "Call in progress" : "Oproep is bezig",
    "You were mentioned" : "Je werd vermeld",
    "Write to conversation" : "Schrijf naar gesprek",
    "Writes event information into a conversation of your choice" : "Schrijft gebeurtenisinformatie in een gesprek naar keuze",
    "Missing email field in header line" : "E-mailveld mist in header-regel",
    "Following lines are invalid: %s" : "De volgende regels zijn onjuist: %s",
    "%1$s invited you to conversation \"%2$s\"." : "%1$s nodigde je uit voor gesprek \"%2$s\".",
    "You were invited to conversation \"%s\"." : "Je bent uitgenodigd voor gesprek  \"%s\".",
    "Conversation invitation" : "Gespreksuitnodiging",
    "Description" : "Beschrijving",
    "You can also dial-in via phone with the following details" : "Je kunt ook via telefoon inbellen met behulp van deze informatie",
    "Dial-in information" : "Inbelinformatie",
    "Meeting ID" : "Vergader-ID",
    "Your PIN" : "Jouw PIN",
    "Click the button below to join the lobby now." : "Klik op de onderstaan knop om in de lobby te komen",
    "Click the link below to join the lobby now." : "Klik op de onderstaande link om in de lobby te komen",
    "Join lobby for \"%s\"" : "Meldt je aan in de lobby voor \"%s\"",
    "Click the button below to join the conversation now." : "Klik op de onderstaande knop om nu deel te nemen aan het gesprek.",
    "Click the link below to join the conversation now." : "Klik op de onderstaande link om nu deel te namen aan het gesprek.",
    "Meeting" : "Vergadering",
    "Password request: %s" : "Wachtwoordverzoek: %s",
    "Private conversation" : "Privégesprek",
    "Deleted user (%s)" : "Verwijderde gebruiker (%s)",
    "Failed to upload call recording" : "Upload gespreksopname mislukt",
    "The recording server failed to upload recording of call {call}. Please reach out to the administration." : "De opnameserver kon de gespreksopname {call} niet uploaden. Neem contact op met de administratie a.u.b.",
    "Share to chat" : "Deel met chat",
    "Dismiss notification" : "Handel melding af",
    "Call recording now available" : "Gespreksopname nu beschikbaar",
    "The recording for the call in {call} was uploaded to {file}." : "De opname van gesprek {call} is geüpload naar {file}",
    "Transcript now available" : "Transcript nu beschikbaar",
    "The transcript for the call in {call} was uploaded to {file}." : "De transcript voor gesprek {call} is geüpload naar {file}",
    "Failed to transcript call recording" : "Transripten van gespreksopname is mislukt",
    "The server failed to transcript the recording at {file} for the call in {call}. Please reach out to the administration." : "De server kon de de opname van gesprek {call} niet transcriberen naar {file}. Neem contact op met de administratie a.u.b.",
    "Call summary now available" : "Gesprekssamenvatting nu beschikbaar",
    "The summary for the call in {call} was uploaded to {file}." : "De samenvatting van gesprek {call} is geüpload naar {file}.",
    "Failed to summarize call recording" : "Samenvatten van gespreksopname is mislukt",
    "The server failed to summarize the recording at {file} for the call in {call}. Please reach out to the administration." : "De server kon gesprek {call} niet samenvatten naar{file}. Neem contact op met de administratie a.u.b.",
    "{user1} invited you to join {roomName} on {remoteServer}" : "{user1} heeft je uitgenodigd om deel te nemen aan {roomName} op {remoteServer}",
    "Accept" : "Accepteren",
    "Decline" : "Afwijzen",
    "{user1} invited you to a federated conversation" : "{user1} nodigde je uit voor een gefederaliseerd gesprek",
    "New message" : "Nieuw bericht",
    "Reminder" : "Herinnering",
    "Notification" : "Melding",
    "Someone reacted in a private conversation" : "Iemand reageerde in een privégesprek",
    "You received a message in a private conversation" : "Je hebt een bericht ontvangen in een privégepsrek",
    "Reminder in a private conversation" : "Herinnering in een privégesprek",
    "Someone mentioned you in a private conversation" : "Iemand heeft je genoemd in een privégesprek",
    "Notification in a private conversation" : "Melding in een privégesprek",
    "Reminder: You in {call}" : "Herinnering: Jij in {call}",
    "Reminder: {user} in {call}" : "Herinnering: {user} in {call}",
    "Reminder: Deleted user in {call}" : "Herinnering: Verwijderde gebruiker in {call}",
    "Reminder: {guest} (guest) in {call}" : "Herinnering: {guest} (gast) in {call}",
    "Reminder: Guest in {call}" : "Herinnering: Gast in {call}",
    "{user} reacted with {reaction}" : "{user} reageerde meth {reaction}",
    "{user} reacted with {reaction} in {call}" : "{user} reageerde met {reaction} in {call}",
    "Deleted user reacted with {reaction} in {call}" : "Verwijderde gebruiker reageerde met {reaction} in {call}",
    "{guest} (guest) reacted with {reaction} in {call}" : "{guest} (gast) reageerde met {reaction} in {call}",
    "Guest reacted with {reaction} in {call}" : "Gast reageerde met {reaction} in {call}",
    "{user} in {call}" : "{user} in {call}",
    "Deleted user in {call}" : "Gebruiker verwijderd in {call}",
    "{guest} (guest) in {call}" : "{guest} (gast) in {call}",
    "Guest in {call}" : "Gast in {call}",
    "{user} sent you a private message" : "{user} heeft je een privébericht gestuurd",
    "{user} sent a message in conversation {call}" : "{user} heeft een bericht gestuurd in gesprek {call}",
    "A deleted user sent a message in conversation {call}" : "Een verwijderde gebruiker heeft een bericht gestuurd in gesprek {call}",
    "{guest} (guest) sent a message in conversation {call}" : "{guest} (gast) heeft een bericht gestuurd in gesprek {call}",
    "A guest sent a message in conversation {call}" : "Een gast heeft een bericht gestuurd in gesprek {call}",
    "{user} replied to your private message" : "{user} heeft op jouw privébericht gereageerd",
    "{user} replied to your message in conversation {call}" : "{user} heeft op jouw bericht gereageerd in gesprek {call}",
    "A deleted user replied to your message in conversation {call}" : "Een verwijderde gebruiker heeft op jouw bericht gereageerd in gesprek {call}",
    "{guest} (guest) replied to your message in conversation {call}" : "{guest} (gast) heeft op jouw bericht gereageerd in gesprek {call}",
    "A guest replied to your message in conversation {call}" : "Een gast heeft op jouw bericht gereageerd in gesprek {call}",
    "Reminder: You in private conversation {call}" : "Herinnering: Jij in een privégesprek {call}",
    "Reminder: A deleted user in private conversation {call}" : "Herinnering: Een verwijderde gebruiker in privégesprek {call}",
    "Reminder: {user} in private conversation" : "Herinnering: {user} in privégesprek",
    "Reminder: You in conversation {call}" : "Herinnering: Jij in gesprek {call}",
    "Reminder: {user} in conversation {call}" : "Herinnering: {user} in gesprek {call}",
    "Reminder: A deleted user in conversation {call}" : "Herinnering: Een verwijderde gebruiker in gesprek {call}",
    "Reminder: {guest} (guest) in conversation {call}" : "Herinnering: {guest} in gesprek {call}",
    "Reminder: A guest in conversation {call}" : "Herinnering: Een gast in gesprek {call}",
    "{user} reacted with {reaction} to your private message" : "{user} heeft op jouw privébericht geantwoord met {reaction}",
    "{user} reacted with {reaction} to your message in conversation {call}" : "{user} heeft met {reactie} gereageerd op jouw bericht in gesprek {call}",
    "A deleted user reacted with {reaction} to your message in conversation {call}" : "Een verwijderde gebruiker heeft met {reactie} gereageerd op jouw bericht in gesprek {call}",
    "{guest} (guest) reacted with {reaction} to your message in conversation {call}" : "{guest} (gast) heeft met {reactie} gereageerd op jouw bericht in gesprek {call}",
    "A guest reacted with {reaction} to your message in conversation {call}" : "Een gast heeft met {reactie} gereageerd op jouw bericht in gesprek {call}",
    "{user} mentioned you in a private conversation" : "{user} heeft jou in een privégesprek vermeld",
    "{user} mentioned group {group} in conversation {call}" : "{user} vermelde groep {group} in gesprek {call}",
    "{user} mentioned team {team} in conversation {call}" : "{user} vermelde team {team} in gesprek {call}",
    "{user} mentioned everyone in conversation {call}" : "{user} vermelde iedereen in gesprek {call}",
    "{user} mentioned you in conversation {call}" : "{user} heeft jou in vermeld in gesprek {call}",
    "A deleted user mentioned group {group} in conversation {call}" : "Een verwijderde gebruiker vermelde groep {group} in gesprek {call}",
    "A deleted user mentioned team {team} in conversation {call}" : "Een verwijderde gebruiker vermelde team {team} in gesprek {call}",
    "A deleted user mentioned everyone in conversation {call}" : "Een verwijderde gebruiker vermelde iedereen in gesprek {call}",
    "A deleted user mentioned you in conversation {call}" : "Een verwijderde gebruiker heeft jou vermeld in gesprek {call}",
    "{guest} (guest) mentioned group {group} in conversation {call}" : "{guest} (gast) vermelde groep {group} in gesprek {call}",
    "{guest} (guest) mentioned team {team} in conversation {call}" : "{guest} (gast) vermelde team {team} in gesprek{call}",
    "{guest} (guest) mentioned everyone in conversation {call}" : "{guest} (gast) vermelde iedereen in gesprek {call}",
    "{guest} (guest) mentioned you in conversation {call}" : "{guest} (gast) heeft jou vermeld in gesprek {call}",
    "A guest mentioned group {group} in conversation {call}" : "Een gast vermelde groep {group} in gesprek {call}",
    "A guest mentioned team {team} in conversation {call}" : "Een gast vermelde team {team} in gesprek {call}",
    "A guest mentioned everyone in conversation {call}" : "Een gast vermelde iedereen in gesprek {call}",
    "A guest mentioned you in conversation {call}" : "Een gast heeft jou vermeld in gesprek {call}",
    "View message" : "Toon bericht",
    "Dismiss reminder" : "Sluit herinnering",
    "View chat" : "Bekijk chat",
    "{user} invited you to a group conversation: {call}" : "{user} nodigde je uit voor een groepsgesprek: {call}",
    "Join call" : "Deelnemen aan oproep",
    "Answer call" : "Oproep beantwoorden",
    "{user} would like to talk with you" : "{user} wil met je spreken",
    "Call back" : "Terugbellen",
    "You missed a call from {user}" : "Je hebt een gesprek gemist van {user}",
    "A group call has started in {call}" : "Groepsgesprek is begonnen in {call}",
    "You missed a group call in {call}" : "Je hebt een groepsgesprek gemist in {call}",
    "{email} is requesting the password to access {file}" : "{email} verzoekt het wachtwoord voor toegang tot {file}",
    "{email} tried to request the password to access {file}" : "{email} heeft geprobeerd het wachtwoord op te vragen voor toegang tot {file}",
    "Someone is requesting the password to access {file}" : "Iemand verzoekt het wachtwoord voor toegang tot {file}",
    "Someone tried to request the password to access {file}" : "Iemand heeft geprobeerd het wachtwoord op te vragen voor toegang tot {file}",
    "Open settings" : "Instellingen openen",
    "Hosted signaling server added" : "Gehoste signaling server toegevoegd",
    "The hosted signaling server is now configured and will be used." : "De gehoste signaleringsserver is nu geconfigureerd en zal worden gebruikt.",
    "Hosted signaling server removed" : "Gehoste signaling server verwijderd",
    "The hosted signaling server was removed and will not be used anymore." : "De gehoste signaleringsserver is verwijderd en zal niet meer worden gebruikt.",
    "Hosted signaling server changed" : "Gehoste signaling server veranderd",
    "The hosted signaling server account has changed the status from \"{oldstatus}\" to \"{newstatus}\"." : "Het account van gehoste signaleringsserver heeft de status gewijzigd van \"{oldstatus}\" naar \"{newstatus}\".",
    "pending" : "in behandeling",
    "active" : "actief",
    "expired" : "verlopen",
    "blocked" : "geblokkeerd",
    "error" : "fout",
    "The certificate of {host} expires in {days} days" : "Het certificaat van {host} loopt af in {days} dagen",
    "The certificate of {host} expired" : "Het certificaat van {host} is afgelopen",
    "Contact via Talk" : "Contacteer via Talk",
    "Open Talk" : "Open Talk",
    "Default" : "Standaard",
    "Presentation" : "Presentatie",
    "Voice room" : "Spraak room",
    "Conversations" : "Gesprekken",
    "Messages in current conversation" : "Berichten in huidig gesprek",
    "{user}" : "{user}",
    "Messages" : "Berichten",
    "{user} in {conversation}" : "{user} in {conversation}",
    "Messages in other conversations" : "Berichten in andere gesprekken",
    "One-to-one rooms always need to show the other users avatar" : "Een-op-een gesprekken moeten altijd de avatar van de andere gebruiker laten zien",
    "Invalid emoji character" : "Ongeldig emoji-teken",
    "Invalid background color" : "Ongeldige achtergrondkleur",
    "Avatar image is not square" : "Avatar afbeelding is niet vierkant",
    "Room {number}" : "Vergaderruimte {number}",
    "Other" : "Andere",
    "Failed to request trial because the trial server is unreachable. Please try again later." : "Het aanvragen van een proefversie is mislukt, omdat de proefserver niet bereikbaar is. Probeer het later opnieuw.",
    "There is a problem with the authentication of this instance. Maybe it is not reachable from the outside to verify it's URL." : "Er is een probleem met authenticatie van deze instantie. Misschien is deze niet van buitenaf bereikbaar om de URL te verifiëren.",
    "Something unexpected happened." : "Er is iets onverwachts gebeurd.",
    "The URL is invalid." : "De URL is ongeldig.",
    "An HTTPS URL is required." : "Een HTTPS-URL is vereist.",
    "The email address is invalid." : "Het e-mailadres is ongeldig.",
    "The language is invalid." : "De taal is ongeldig.",
    "The country is invalid." : "Het land is ongeldig.",
    "There is a problem with the request of the trial. Please check your logs for further information." : "Er is een probleem met de aanvraag van de proefversie. Controleer de logs voor meer informatie.",
    "Too many requests are send from your servers address. Please try again later." : "Er worden te veel verzoeken verzonden vanaf het adres van je server. Probeer het later opnieuw.",
    "There is already a trial registered for this Nextcloud instance." : "Er is al een proefversie geregistreerd voor deze Nextcloud-instantie.",
    "Something unexpected happened. Please try again later." : "Er is iets onverwachts gebeurd. Probeer het later opnieuw.",
    "Failed to request trial because the trial server behaved wrongly. Please try again later." : "Het aanvragen van een proefversie is mislukt, vanwege onjuist gedrag van de proefserver. Probeer het later opnieuw.",
    "Trial requested but failed to get account information. Please check back later." : "De proefperiode is aangevraagd, maar het ophalen van accountinformatie is mislukt. Controleer het later nog eens.",
    "There is a problem with the authentication of this request. Maybe it is not reachable from the outside to verify it's URL." : "Er is een probleem met de authenticatie van dit verzoek. Misschien is het niet van buitenaf bereikbaar om de URL te verifiëren.",
    "Failed to fetch account information because the trial server behaved wrongly. Please check back later." : "Het ophalen van accountinformatie is mislukt, vanwege onjuist gedrag van de proefserver. Controleer het later nog eens.",
    "There is a problem with fetching the account information. Please check your logs for further information." : "Er is een probleem met het ophalen van de accountgegevens. Controleer de logs voor meer informatie.",
    "There is no such account registered." : "Dit account is niet geregistreerd.",
    "Failed to fetch account information because the trial server is unreachable. Please check back later." : "Het ophalen van accountinformatie is mislukt, omdat de proefserver niet bereikbaar is. Controleer het later opnieuw.",
    "Deleting the hosted signaling server account failed. Please check back later." : "Het verwijderd van het account van de gehoste signaleringsserver is mislukt. Controleer het later opnieuw.",
    "Failed to delete the account because the trial server behaved wrongly. Please check back later." : "Het account kan niet worden verwijderd, vanwege onjuist gedrag van de proefserver. Controleer het later opnieuw.",
    "There is a problem with deleting the account. Please check your logs for further information." : "Er is een probleem met het verwijderen van het account. Controleer de logboeken voor meer informatie.",
    "Too many requests are sent from your servers address. Please try again later." : "Er worden te veel verzoeken verzonden vanaf je serveradres. Probeer het later opnieuw.",
    "Failed to delete the account because the trial server is unreachable. Please check back later." : "Het account kan niet worden verwijderd omdat de proefserver niet bereikbaar is. Controleer het later opnieuw.",
    "Note to self" : "Notitie aan mijzelf",
    "A place for your private notes, thoughts and ideas" : "Een plek voor je privénotities, gedachten en ideeën",
    "Transcript is AI generated and may contain mistakes" : "Transript is gegenereerd via AI en kan fouten bevatten",
    "Summary is AI generated and may contain mistakes" : "Samenvatting is gegenereerd via AI en kan fouten bevatten",
    "**Nextcloud Talk** is a secure, self-hosted communication platform that integrates seamlessly with the Nextcloud ecosystem.\n\n#### Key Features of Nextcloud Talk:\n\n* Chat and messaging in private and group chats\n* Voice and video calls\n* File sharing and integration with other Nextcloud apps\n* Customizable conversation settings, moderation and privacy controls\n* Web, desktop and mobile (iOS and Android)\n* Private & secure communication\n\n Find out more in the [user documentation](https://docs.nextcloud.com/server/latest/user_manual/en/talk/index.html)." : "**Nextcloud Talk** is a veilige, zelf-gehost communicatie platform wat volledig integreerd met het Nextcloud ecosysteem.\n\n#### Belangrijkste mogelijkheden van Nextcloud Talk:\n\n* Chat and berichtjes in prive en groepsgesprekken\n* Audio en video gesprekken\n* Bestanden delen en integratie met andere Nextcloud applicaties\n* Aanpasbare gespreksinstellingen, moderatie en privacy instellingen\n* Browser, desktop en mobiele (iOS and Android) toegang\n* Private & veilige communicatie\n\nVind meer informatie in de [gebruikershandleiding](https://docs.nextcloud.com/server/latest/user_manual/nl/talk/index.html).",
    "# Welcome to Nextcloud Talk\n\nNextcloud Talk is a private and powerful messaging app that integrates with Nextcloud. Chat in private or group conversations, collaborate over voice and video calls, organize webinars and events, customize your conversations and more." : "# Welkom bij Nextcloud Talk\n\nNextcloud Talk is een privacy-vriendelijke en geavanceerde chat applicatie die diep met Nextcloud integreerd. Chat in privé of of groepsgesprekken, werk samen aan documenten of whiteboards tijdens audio of video gesprekken, webinars en gebeurtenissen organiseren, gesprekken modereren en nog veel meer.",
    "## ✨ Do more with Smart Picker\n\nSimply type \"/\" or go to the \"+\" menu to open the Smart Picker where you can attach various content to your messages. You can configure the Smart Picker to be able to add items from Nextcloud apps, GIFs, map locations, AI generated content and much more." : "## ✨ Doe meer met Smart Picker\n\nTyp eenvoudig \"/\" of ga naar het menu \"+\" om de Smart Picker te openen, waar je verschillende inhoud aan je berichten kunt toevoegen. je kunt de Smart Picker zo configureren dat je items uit Nextcloud-apps, GIF's, kaartlocaties, door AI gegenereerde inhoud en nog veel meer kunt toevoegen.",
    "Andorra" : "Andorra",
    "United Arab Emirates" : "Verenigde Arabische Emiraten",
    "Afghanistan" : "Afghanistan",
    "Antigua and Barbuda" : "Antigua en Barbuda",
    "Anguilla" : "Anguilla",
    "Albania" : "Albanië",
    "Armenia" : "Armenië",
    "Angola" : "Angola",
    "Antarctica" : "Antarctica",
    "Argentina" : "Argentinië",
    "American Samoa" : "Amerikaans Samoa",
    "Austria" : "Oostenrijk",
    "Australia" : "Australië",
    "Aruba" : "Aruba",
    "Åland Islands" : "Åland",
    "Azerbaijan" : "Azerbeidjan",
    "Bosnia and Herzegovina" : "Bosnië en Herzegovina",
    "Barbados" : "Barbados",
    "Bangladesh" : "Bangladesh",
    "Belgium" : "België",
    "Burkina Faso" : "Burkina Faso",
    "Bulgaria" : "Bulgarije",
    "Bahrain" : "Bahrein",
    "Burundi" : "Burundi",
    "Benin" : "Benin",
    "Saint Barthélemy" : "Saint Barthélemy",
    "Bermuda" : "Bermuda",
    "Brunei Darussalam" : "Brunei",
    "Bolivia, Plurinational State of" : "Bolivia, Plurinationale Staat ",
    "Bonaire, Sint Eustatius and Saba" : "Bonaire, Sint Eustatius en Saba",
    "Brazil" : "Brazilië",
    "Bahamas" : "Bahama's",
    "Bhutan" : "Bhutan",
    "Bouvet Island" : "Bouveteiland",
    "Botswana" : "Botswana",
    "Belarus" : "Wit-Rusland",
    "Belize" : "Belize",
    "Canada" : "Canada",
    "Cocos (Keeling) Islands" : "Cocoseilanden",
    "Congo, the Democratic Republic of the" : "Congo, Democratische Republiek",
    "Central African Republic" : "Centraal Afrikaanse Republiek",
    "Congo" : "Congo",
    "Switzerland" : "Zwitserland",
    "Côte d'Ivoire" : "Ivoorkust",
    "Cook Islands" : "Cookeilanden",
    "Chile" : "Chili",
    "Cameroon" : "Kameroen",
    "China" : "China",
    "Colombia" : "Colombia",
    "Costa Rica" : "Costa Rica",
    "Cuba" : "Cuba",
    "Cabo Verde" : "Kaapverdië",
    "Curaçao" : "Curaçao",
    "Christmas Island" : "Christmaseiland",
    "Cyprus" : "Cyprus",
    "Czechia" : "Tsjechië",
    "Germany" : "Duitsland",
    "Djibouti" : "Djibouti",
    "Denmark" : "Denemarken",
    "Dominica" : "Dominica",
    "Dominican Republic" : "Dominicaanse Republiek",
    "Algeria" : "Algerije",
    "Ecuador" : "Ecuador",
    "Estonia" : "Estland",
    "Egypt" : "Egypte",
    "Western Sahara" : "Westelijke Sahara",
    "Eritrea" : "Eritrea",
    "Spain" : "Spanje",
    "Ethiopia" : "Ethiopië",
    "Finland" : "Finland",
    "Fiji" : "Fiji",
    "Falkland Islands (Malvinas)" : "Falklandeilanden",
    "Micronesia, Federated States of" : "Micronesia, Federale Staten van",
    "Faroe Islands" : "Faeröer",
    "France" : "Frankrijk",
    "Gabon" : "Gabon",
    "United Kingdom of Great Britain and Northern Ireland" : "Verenigd Koninkrijk",
    "Grenada" : "Grenada",
    "Georgia" : "Georgië",
    "French Guiana" : "Frans-Guyana",
    "Guernsey" : "Guernsey",
    "Ghana" : "Ghana",
    "Gibraltar" : "Gibraltar",
    "Greenland" : "Groenland",
    "Gambia" : "Gambia",
    "Guinea" : "Guinea",
    "Guadeloupe" : "Guadeloupe",
    "Equatorial Guinea" : "Equatoriaal Guinea",
    "Greece" : "Griekenland",
    "South Georgia and the South Sandwich Islands" : "Zuid-Georgia en de Zuidelijke Sandwicheilanden",
    "Guatemala" : "Guatemala",
    "Guam" : "Guam",
    "Guinea-Bissau" : "Guinea-Bissau",
    "Guyana" : "Guyana",
    "Hong Kong" : "Hong Kong",
    "Heard Island and McDonald Islands" : "Heard en McDonaldeilanden",
    "Honduras" : "Honduras",
    "Croatia" : "Kroatië",
    "Haiti" : "Haïti",
    "Hungary" : "Hongarije",
    "Indonesia" : "Indonesië",
    "Ireland" : "Ierland",
    "Israel" : "Israel",
    "Isle of Man" : "Man (eiland)",
    "India" : "India",
    "British Indian Ocean Territory" : "Brits Indische Oceaanterritorium",
    "Iraq" : "Irak",
    "Iran, Islamic Republic of" : "Iran, Islamitische republiek",
    "Iceland" : "IJsland",
    "Italy" : "Italië",
    "Jersey" : "Jersey",
    "Jamaica" : "Jamaica",
    "Jordan" : "Jordanië",
    "Japan" : "Japan",
    "Kenya" : "Kenia",
    "Kyrgyzstan" : "Kirgizië",
    "Cambodia" : "Cambodja",
    "Kiribati" : "Kiribati",
    "Comoros" : "Komoren",
    "Saint Kitts and Nevis" : "Saint Kitts and Nevis",
    "Korea, Democratic People's Republic of" : "Korea, Democratische Volksrepubliek",
    "Korea, Republic of" : "Korea, Republiek",
    "Kuwait" : "Koeweit",
    "Cayman Islands" : "Kaaimaneilanden",
    "Kazakhstan" : "Kazachstan",
    "Lao People's Democratic Republic" : "Laos",
    "Lebanon" : "Libanon",
    "Saint Lucia" : "Saint Lucia",
    "Liechtenstein" : "Liechtenstein",
    "Sri Lanka" : "Sri Lanka",
    "Liberia" : "Liberia",
    "Lesotho" : "Lesotho",
    "Lithuania" : "Litouwen",
    "Luxembourg" : "Luxemburg",
    "Latvia" : "Letland",
    "Libya" : "Libië",
    "Morocco" : "Marokko",
    "Monaco" : "Monaco",
    "Moldova, Republic of" : "Moldavië, Republiek",
    "Montenegro" : "Montenegro",
    "Saint Martin (French part)" : "Saint Martin",
    "Madagascar" : "Madagascar",
    "Marshall Islands" : "Marshalleilanden",
    "North Macedonia" : "Noord-Macedonië",
    "Mali" : "Mali",
    "Myanmar" : "Myanmar",
    "Mongolia" : "Mongolië",
    "Macao" : "Macao",
    "Northern Mariana Islands" : "Noordelijke Marianen",
    "Martinique" : "Martinique",
    "Mauritania" : "Mauretanië",
    "Montserrat" : "Montserrat",
    "Malta" : "Malta",
    "Mauritius" : "Mauritius",
    "Maldives" : "Malediven",
    "Malawi" : "Malawi",
    "Mexico" : "Mexico",
    "Malaysia" : "Maleisië",
    "Mozambique" : "Mozambique",
    "Namibia" : "Namibië",
    "New Caledonia" : "Nieuw Caledonië",
    "Niger" : "Niger",
    "Norfolk Island" : "Norfolk {eiland)",
    "Nigeria" : "Nigeria",
    "Nicaragua" : "Nicaragua",
    "Netherlands" : "Nederland",
    "Norway" : "Noorwegen",
    "Nepal" : "Nepal",
    "Nauru" : "Nauru",
    "Niue" : "Niue",
    "New Zealand" : "Nieuw Zeeland",
    "Oman" : "Oman",
    "Panama" : "Panama",
    "Peru" : "Peru",
    "French Polynesia" : "Frans-Polynesië",
    "Papua New Guinea" : "Papoea-Nieuw-Guinea",
    "Philippines" : "Filippijnen",
    "Pakistan" : "Pakistan",
    "Poland" : "Polen",
    "Saint Pierre and Miquelon" : "Saint-Pierre en Miquelon",
    "Pitcairn" : "Pitcairn",
    "Puerto Rico" : "Puerto Rico",
    "Palestine, State of" : "Palestina",
    "Portugal" : "Portugal",
    "Palau" : "Palau",
    "Paraguay" : "Paraguay",
    "Qatar" : "Katar",
    "Réunion" : "Réunion",
    "Romania" : "Roemenië",
    "Serbia" : "Servië",
    "Russian Federation" : "Russische Federatie",
    "Rwanda" : "Rwanda",
    "Saudi Arabia" : "Saoedi-Arabië",
    "Solomon Islands" : "Salomonseilanden",
    "Seychelles" : "Seychellen",
    "Sudan" : "Soedan",
    "Sweden" : "Zweden",
    "Singapore" : "Singapore",
    "Saint Helena, Ascension and Tristan da Cunha" : "Sint-Helena, Ascension en Tristan da Cunha",
    "Slovenia" : "Slovenië",
    "Svalbard and Jan Mayen" : "Spitsbergen en Jan Mayen",
    "Slovakia" : "Slowakije",
    "Sierra Leone" : "Sierra Leone",
    "San Marino" : "San Marino",
    "Senegal" : "Senegal",
    "Somalia" : "Somalië",
    "Suriname" : "Suriname",
    "South Sudan" : "Zuid-Soedan",
    "Sao Tome and Principe" : "Sao Tomé en Principe",
    "El Salvador" : "El Salvador",
    "Sint Maarten (Dutch part)" : "Sint Maarten",
    "Syrian Arab Republic" : "Syrië",
    "Eswatini" : "Eswatini",
    "Turks and Caicos Islands" : "Turks- en Caicoseilanden",
    "Chad" : "Tsjaad",
    "French Southern Territories" : "Franse Zuidelijke en Antarctische Gebieden",
    "Togo" : "Togo",
    "Thailand" : "Thailand",
    "Tajikistan" : "Tadzjikistan",
    "Tokelau" : "Tokelau",
    "Timor-Leste" : "Oost-Timor",
    "Turkmenistan" : "Turkmenistan",
    "Tunisia" : "Tunisië",
    "Tonga" : "Tonga",
    "Turkey" : "Turkije",
    "Trinidad and Tobago" : "Trinidad en Tobago",
    "Tuvalu" : "Tuvalu",
    "Taiwan, Province of China" : "Taiwan",
    "Tanzania, United Republic of" : "Tanzania",
    "Ukraine" : "Oekraine",
    "Uganda" : "Oeganda",
    "United States Minor Outlying Islands" : "Kleine afgelegen eilanden van de Verenigde Staten",
    "United States of America" : "Verenigde Staten van Amerika",
    "Uruguay" : "Uruguay",
    "Uzbekistan" : "Oezbekistan",
    "Holy See" : "Heilige Stoel",
    "Saint Vincent and the Grenadines" : "Saint Vincent en de Grenadines",
    "Venezuela, Bolivarian Republic of" : "Venezuela, Bolivariaanse Republiek",
    "Virgin Islands, British" : "Maagdeneilanden, Britse",
    "Virgin Islands, U.S." : "Maagdeneilanden, Amerikaanse ",
    "Viet Nam" : "Vietnam",
    "Vanuatu" : "Vanuatu",
    "Wallis and Futuna" : "Wallis en Futuna",
    "Samoa" : "Samoa",
    "Yemen" : "Jemen",
    "Mayotte" : "Mayotte",
    "South Africa" : "Zuid-Afrika",
    "Zambia" : "Zambia",
    "Zimbabwe" : "Zimbabwe",
    "Background blur" : "Achtergrondvervaging",
    "Could not check for WASM loading support. Please check manually if your web server serves `.wasm` files." : "Was niet in staat om WASM ondersteuning te verifieren. Kijk aub met de hand of uw webserver `.wasm` bestanden kan serveren naar de browser.",
    "Your web server is not properly set up to deliver `.wasm` files. This is typically an issue with the Nginx configuration. For background blur it needs an adjustment to also deliver `.wasm` files. Compare your Nginx configuration to the recommended configuration in our documentation." : "Uw webserver is niet correct ingesteld om `.wasm`-bestanden te leveren. Dit is meestal een probleem met de Nginx-configuratie. Voor achtergrondvervaging is een aanpassing nodig om ook `.wasm`-bestanden te leveren. Vergelijk uw Nginx-configuratie met de aanbevolen configuratie in onze documentatie.",
    "Talk configuration values" : "Talk configuratie waarden",
    "Forcing a call duration is only supported with system cron. Please enable system cron or remove the `max_call_duration` configuration." : "Het forceren van een gespreksduur wordt alleen ondersteund met systeemcron. Schakel systeemcron in of verwijder de `max_call_duration`-configuratie.",
    "Small `max_call_duration` values (currently set to %d) are not enforceable due to technical limitations. The background job is only executed every 5 minutes, so use at own risk." : "Kleine `max_call_duration`-waarden (momenteel ingesteld op %d) zijn niet afdwingbaar vanwege technische beperkingen. De achtergrondtaak wordt slechts elke 5 minuten uitgevoerd, dus gebruik dit op eigen risico.",
    "Federation" : "Federatie",
    "It is highly recommended to configure \"memcache.locking\" when Talk Federation is enabled." : "Het wordt sterk aanbevolen om \"memcache.locking\" te configureren wanneer Talk Federation is ingeschakeld.",
    "High-performance backend" : "High-performance backend",
    "No High-performance backend configured - Running Nextcloud Talk without the High-performance backend only scales for very small calls (max. 2-3 participants). Please set up the High-performance backend to ensure calls with multiple participants work seamlessly." : "Geen High-performance backend geconfigureerd. Als u Nextcloud Talk gebruikt zonder de High-performance backend, werkt dit alleen soepel voor zeer kleine gesprekken (max. 2-5 deelnemers). Insalleer de High-performance backend om ervoor te zorgen dat gesprekken met grotere aantallen deelnemers goed verlopen.",
    "Running the High-performance backend \"conversation_cluster\" mode is deprecated and will no longer be supported in the upcoming version. The High-performance backend supports real clustering nowadays which should be used instead." : "Het uitvoeren van de High-performance backend \"conversation_cluster\"-modus is verouderd en wordt niet langer ondersteund in de komende versie. De High-performance backend ondersteunt tegenwoordig echte clustering, die in plaats daarvan gebruikt zou moeten worden.",
    "Defining multiple High-performance backends is deprecated and will no longer be supported in the upcoming version. Instead a load-balancer should be set up together with clustered signaling servers and configured in the Talk settings." : "Het definiëren van meerdere High-performance backends is verouderd en wordt niet langer ondersteund in de komende versie. In plaats daarvan moet een load-balancer worden ingesteld samen met geclusterde signaleringsservers en geconfigureerd in de Talk-instellingen.",
    "High-performance backend not configured correctly" : "High-performance backend niet correct geconfigureerd",
    "Error: Cannot connect to server" : "Fout: Kan niet verbinden met de server",
    "Error: Server did not respond with proper JSON" : "Fout: Server reageerde niet met een juiste JSON",
    "Error: Certificate expired" : "Waarschuwing: servercertificaat is verlopen",
    "Error: System times of Nextcloud server and High-performance backend server are out of sync. Please make sure that both servers are connected to a time-server or manually synchronize their time." : "Fout: Systeemtijden van Nextcloud-server en High-performance backend-server zijn niet gesynchroniseerd. Zorg ervoor dat beide servers zijn verbonden met een tijdserver of synchroniseer hun tijd handmatig.",
    "Could not get version" : "Kan versie niet verkrijgen",
    "Error: Running version: {version}; Server needs to be updated to be compatible with this version of Talk" : "Fout: Versie in gebruik: {version}; De server dient geüpdate te worden om compatibel te zijn met deze versie van Talk",
    "Error: Server responded with: {error}" : "Fout: Server gaf foutmelding: {error}",
    "Error: Unknown error occurred" : "Fout: Onbekende fout opgetreden!",
    "Warning: Running version: {version}; Server does not support all features of this Talk version, missing features: {features}" : "Waarschuwwing: Huidige versie: {version}; Server ondersteund niet alle mogelijkheden van deze Talk versie, u mist: {features}",
    "It is highly recommended to configure a memory cache when running Nextcloud Talk with a High-performance backend." : "Het wordt sterk aanbevolen om een ​​geheugencache te configureren wanneer u Nextcloud Talk uitvoert met een High-performance backend.",
    "Recording backend" : "Opname backend",
    "Using the recording backend requires a High-performance backend." : "Om de opname-backend te kunnen gebruiken, is de High Performance backend vereist.",
    "No recording backend configured" : "Geen opname-backend geconfigureerd",
    "SIP configuration" : "SIP configuratie",
    "Using the SIP functionality requires a High-performance backend." : "Voor het gebruik van de SIP-functionaliteit is een backend met hoge prestaties vereist.",
    "No SIP backend configured" : "Geen SIP-backend geconfigureerd",
    "Invalid date, date format must be YYYY-MM-DD" : "Ongeldige datum, formaat is YYYY-MM-DD",
    "Conversation not found" : "Gesprek niet gevonden.",
    "Path is already shared with this conversation" : "Pad is al gedeeld met dit gesprek",
    "Chat, video & audio-conferencing using WebRTC" : "Chat, video & audio-conferencing via WebRTC",
    "Chat, video & audio-conferencing using WebRTC\n\n* 💬 **Chat** Nextcloud Talk comes with a simple text chat, allowing you to share or upload files from your Nextcloud Files app or local device and mention other participants.\n* 👥 **Private, group, public and password protected calls!** Invite someone, a whole group or send a public link to invite to a call.\n* 🌐 **Federated chats** Chat with other Nextcloud users on their servers\n* 💻 **Screen sharing!** Share your screen with the participants of your call.\n* 🚀 **Integration with other Nextcloud apps** like Files, Calendar, User status, Dashboard, Flow, Maps, Smart picker, Contacts, Deck, and many more.\n* 🌉 **Sync with other chat solutions** With [Matterbridge](https://github.com/42wim/matterbridge/) being integrated in Talk, you can easily sync a lot of other chat solutions to Nextcloud Talk and vice-versa." : "Chat, video & audio-conferencing met WebRTC\n\n* 💬 **Chat** Nextcloud Talk komt met een eenvoudige tekstchat, maakt het mogelijk om bestanden te delen en uploaden vanuit je Netxcloud Bestanden-app of je lokale apparaat en het noemen van andere deelnemers.\n* 👥 **Privé-, groep-, publieke en wachtwoordbeveiligde gesprekken!** Nodig iemand uit, of een hele groep of verstuur een openbare link om mensen uit te nodigen voor een gesprek.\n* 🌐 **Federated chats** Chat met andere gebruikers op hun Nextcloud servers\n* 💻 **Schermdelen!** Deel je scherm met de deelnemers van je gesprek.\n* 🚀 **Integratie met andere Nextcloud apps** zoals Bestanden, Agenda, Gebruikersstatus, Dashboard, Flow, Kaarten, Smart Picker, Contacten, Deck en vele andere.\n* 🌉 **Sync met andere chat-oplossingen** Met [Matterbridge](https://github.com/42wim/matterbridge/) geïntegreerd in Talk, kan je eenvoudig veel andere chat-oplossingen met Nextcloud Tals en vice versa.",
    "Leave call" : "Verlaat oproep",
    "Navigating away from the page will leave the call in {conversation}" : "Als je wegnavigeert van deze pagina, verlaat je het gesprek in {conversatie}",
    "Stay in call" : "Blijf in de oproep",
    "Error occurred when getting the conversation information" : "Fout opgetreden tijdens het ophalen van de gespreksinformatie",
    "Discuss this file" : "Bespreek dit bestand",
    "Share this file with others to discuss it" : "Deel dit bestand om met anderen te bespreken",
    "Share this file" : "Deel dit bestand",
    "Join conversation" : "Deelnemen aan gesprek",
    "This conversation is password-protected." : "Dit gesprek is beveiligd met een wachtwoord.",
    "We have detected multiple invalid password attempts from your IP. Therefore your next attempt is throttled up to 30 seconds." : "We hebben meerdere ongeldige wachtwoord pogingen gedetecteerd vanaf jouw IP adres. Je volgende poging is daarom vertraagd met maximaal 30 seconden.",
    "The password is wrong. Try again." : "Het wachtwoord is verkeerd. Probeer het opnieuw.",
    "Password" : "Wachtwoord",
    "Submit" : "Verwerken",
    "Error requesting the password." : "Fout bij opvragen wachtwoord.",
    "Request password" : "Aanvragen wachtwoord",
    "This conversation has ended" : "Dit gesprek is beeindigd",
    "Error occurred when joining the conversation" : "Er is een fout opgetreden bij het deelnemen aan het gesprek",
    "Close Talk sidebar" : "Sluit Talk zijbalk",
    "Open Talk sidebar" : "Open Talk zijbalk",
    "Everyone" : "Iedereen",
    "Users and moderators" : "Gebruikers en moderatoren",
    "Moderators only" : "Alleen moderators",
    "Disable calls" : "Gesprekken uitschakelen",
    "Save changes" : "Wijzigingen bewaren",
    "Saving …" : "Opslaan ...",
    "Saved!" : "Opgeslagen!",
    "Limit to groups" : "Beperk tot groepen",
    "When at least one group is selected, only people of the listed groups can be part of conversations." : "Als er minimaal één groep is geselecteerd, kunnen alleen mensen uit de geslecteerde groepen deelnemen aan de gesprekken.",
    "Guests can still join public conversations." : "Gasten kunnen nog deelnemen aan openbare gesprekken.",
    "Users that cannot use Talk anymore will still be listed as participants in their previous conversations and also their chat messages will be kept." : "Gebruikers die Talk niet meer kunnen gebruiken, worden nog steeds als deelnemen in eerdere gesprekken getoond en ook hun chat-berichten worden nog steeds getoond.",
    "Limit using Talk" : "Beperk gebruik van Talk",
    "Limit creating a public and group conversation" : "Beperk maken van openbare en groepsgesprekken",
    "Limit creating conversations" : "Beperk aanmaken gesprekken",
    "Limit starting a call" : "Beperk het starten van een oproep",
    "Limit starting calls" : "Beperk het starten van oproepen",
    "When a call has started, everyone with access to the conversation can join the call." : "Zodra een oproep is gestart, kan iedereen met toegang tot het gesprek deelnemen aan de oproep.",
    "Description is not provided" : "Beschrijving is niet verstrekt",
    "Locked for moderators" : "Vergrendeld voor moderators",
    "Enabled" : "Ingeschakeld",
    "Disabled" : "Uitgeschakeld",
    "Bots settings" : "Bots instellingen",
    "State" : "Status",
    "Name" : "Naam",
    "Last error" : "Laatste fout",
    "Total errors count" : "Totaal aantal fouten",
    "Find more bots" : "Vind meer bots",
    "Beta" : "Bèta",
    "Permissions" : "Machtigingen",
    "Select groups …" : "Selecteer groepen …",
    "All messages" : "Alle berichten",
    "@-mentions only" : "Alleen @-vermeldingen",
    "Off" : "Uit",
    "General settings" : "Algemene instellingen",
    "Default notification settings" : "Standaard meldingsinstellingen",
    "Default group notification" : "Standaard groepsmelding",
    "Default group notification for new groups" : "Standaard groepsmelding voor nieuwe groepen",
    "Integration into other apps" : "Integratie in andere apps",
    "Allow conversations on files" : "Sta gesprekken in bestanden toe",
    "Allow conversations on public shares for files" : "Sta gesprekken toe op openbaar gedeelde bestanden",
    "Enable encryption" : "Schakel encryptie in",
    "By clicking the button above the information in the form is sent to the servers of Struktur AG. You can find further information at {linkstart}spreed.eu{linkend}." : "Door op de knop hierboven te klikken wordt de informatie in het formulier naar de servers van Struktur AG gestuurd. Meer informatie vind je op {linkstart}spreed.eu{linkend}.",
    "Pending" : "Onderhanden",
    "Error" : "Fout",
    "Blocked" : "Geblokkeerd",
    "Active" : "Actief",
    "Expired" : "Vervallen",
    "Never" : "Nooit",
    "The trial could not be requested. Please try again later." : "Het proces kon niet worden aangevraagd. Probeer het later opnieuw.",
    "The account could not be deleted. Please try again later." : "Het account kon niet worden verwijderd. Probeer het later opnieuw.",
    "Our partner Struktur AG provides a service where a hosted signaling server can be requested. For this you only need to fill out the form below and your Nextcloud will request it. Once the server is set up for you the credentials will be filled automatically. This will overwrite the existing signaling server settings." : "Onze partner Struktur AG biedt een service waarbij een gehoste signaleringsserver kan worden aangevraagd. Hiervoor hoef je alleen maar het onderstaande formulier in te vullen en je Nextcloud zal erom vragen. Zodra de server voor je is ingesteld, worden de inloggegevens automatisch ingevuld. Hierdoor worden de bestaande instellingen van de signaleringsserver overschreven.",
    "URL of this Nextcloud instance" : "URL van deze Nextcloud server",
    "Full name of the user requesting the trial" : "Volledige naam van de gebruiker die de proef aanvraagt",
    "Email of the user" : "E-mailadres van de gebruiker",
    "Language" : "Taal",
    "Country" : "Land",
    "Request signaling server trial" : "Verzoek proefperiode signaleringsserver",
    "You can see the current status of your hosted signaling server in the following table." : "Je kunt de huidige status van je gehoste signaleringsserver in de volgende tabel zien.",
    "Status" : "Status",
    "Created at" : "Gemaakt op",
    "Expires at" : "Vervalt op",
    "Limits" : "Limieten",
    "Yes" : "Ja",
    "No" : "Nee",
    "Delete the signaling server account" : "Verwijder het signaleringsserveraccount",
    "_%n user_::_%n users_" : ["%n gebruiker","%n gebruikers"],
    "Installed version: {version}" : "Geïnstalleerde versie: {version}",
    "You can install the Matterbridge to link Nextcloud Talk to some other services, visit their {linkstart1}GitHub page{linkend} for more details. Downloading and installing the app can take a while. In case it times out, please install it manually from the {linkstart2}Nextcloud App Store{linkend}." : "Je kunt de Matterbridge installeren om Nextcloud Talk te linken naar andere diensten, bezoek hun {linkstart1}GitHub pagina{linkend} voor nadere details. Het downloaden en installeren van de app kan even duren. Mocht er een time-out plaatsvinden, kan de app handmatig geïnstalleerd worden via de {linkstart2}Nextcloud App Store{linkend}.",
    "Matterbridge binary was not found or couldn't be executed." : "Het Matterbridge uitvoeringsbestand kon niet gevonden of uitgevoerd worden.",
    "You can also set the path to the Matterbridge binary manually via the config. Check the {linkstart}Matterbridge integration documentation{linkend} for more information." : "Je kunt het pad naar het binaire bestand van Matterbridge ook handmatig instellen via de configuratie. Raadpleeg de {linkstart} Matterbridge-integratiedocumentatie {linkend} voor meer informatie.",
    "Downloading …" : "Bezig met downloaden ...",
    "Install Talk Matterbridge" : "Installeer Talk Matterbridge",
    "Failed to execute Matterbridge binary." : "Kon de Matterbridge binary niet uitvoeren",
    "Matterbridge integration" : "Matterbridge integratie",
    "Enable Matterbridge integration" : "Matterbridge integratie inschakelen",
    "Status: Checking connection" : "Status: Controleren verbinding",
    "OK: Running version: {version}" : "OK: Actuele versie: {version}",
    "Validate SSL certificate" : "Valideer SSL certificaat",
    "Delete this server" : "Verwijder deze server",
    "Test this server" : "Test deze server",
    "Disabled for all calls" : "Uitgeschakeld voor alle gesprekken",
    "Enabled for all calls" : "Ingeschakeld voor alle gesprekken",
    "Configurable on conversation level by moderators" : "Instelbaar op gespreksniveau door moderators",
    "Shared secret" : "Gedeeld geheim",
    "Recording consent" : "Toestemming opname",
    "Recording transcription" : "Transcriptie wordt opgenomen",
    "SIP configuration saved!" : "SIP configuratie opgeslagen!",
    "Restrict SIP configuration" : "Beperk SIP configuratie",
    "Enable SIP configuration" : "Inschakelen SIP configuratie",
    "Only users of the following groups can enable SIP in conversations they moderate" : "Alleen gebruikers uit de volgende groepen kunnen SIP inschakelen in de gespreken die zij modereren",
    "Phone number (Country)" : "Telefoonnummer (Country)",
    "This information is sent in invitation emails as well as displayed in the sidebar to all participants." : "Deze informatie wordt verzonden in uitnodigingsmails en ook getoond in de zijbalk voor alle deelnemers.",
    "Error code" : "Foutcode",
    "High-performance backend URL" : "High-performance backend URL",
    "High-performance backend settings saved" : "High-performance backend instellingen opgeslagen",
    "STUN server URL" : "STUN server URL",
    "The server address is invalid" : "Het server adres is ongeldig",
    "STUN settings saved" : "STUN instellingen opgeslagen",
    "STUN servers" : "STUN servers",
    "A STUN server is used to determine the public IP address of participants behind a router." : "De STUN server wordt gebruikt om het openbare IP-adres van deelnemers achter een router vast te stellen.",
    "Add a new STUN server" : "Nieuwe STUN server toevoegen",
    "{schema} scheme must be used with a domain" : "{schema} schema moet worden gebruikt met een domein",
    "{option1} and {option2}" : "{option1} en {option2}",
    "{option} only" : "{option} alleen",
    "OK: Successful ICE candidates returned by the TURN server" : "OK: Succesvolle ICE-kandidaten geretourneerd door de TURN-server",
    "Error: No working ICE candidates returned by the TURN server" : "Fout: geen werkende ICE-kandidaten geretourneerd door de TURN-server",
    "Testing whether the TURN server returns ICE candidates" : "Controleren of de TURN-server ICE-kandidaten retourneert",
    "TURN server schemes" : "TURN server schema's",
    "TURN server URL" : "TURN server URL",
    "TURN server secret" : "TURN server secret",
    "TURN server protocols" : "TURN server protocollen",
    "A TURN server is used to proxy the traffic from participants behind a firewall. If individual participants cannot connect to others a TURN server is most likely required. See {linkstart}this documentation{linkend} for setup instructions." : "Een TURN server wordt gebruikt om verkeer van deelnemers achter een firewall te proxyen. Als individuele deelnemers niet rechtstreeks met anderen kunnen verbinden, is TURN server vermoedelijk vereist. Zie {linkstart}deze documentatie{linkend} voor instructies.",
    "TURN settings saved" : "TURN instellingen opgeslagen",
    "TURN servers" : "TURN servers",
    "Add a new TURN server" : "Nieuwe TURN server toevoegen",
    "Failed" : "Mislukt",
    "OK" : "OK",
    "Checking …" : "Controleren ...",
    "Failed: WebAssembly is disabled or not supported in this browser. Please enable WebAssembly or use a browser with support for it to do the check." : "Mislukt: WebAssembly is uitgeschakeld of niet ondersteund in deze browser. Schakel WebAssembly in of gebruik een browser met ondersteuning ervoor voor de controle.",
    "Failed: \".wasm\" and \".tflite\" files were not properly returned by the web server. Please check \"System requirements\" section in Talk documentation." : "Mislukt: \".wasm\" and \".tflite\" bestanden waren niet juist geretourneerd door de webserver. Controleer \"Systeemvereisten\" sectie in de Talk documentatie.",
    "OK: \".wasm\" and \".tflite\" files were properly returned by the web server." : "OK: \".wasm\"- en \".tflite\"-bestanden zijn correct geretourneerd door de webserver.",
    "It seems that the PHP and Apache configuration is not compatible. Please note that PHP can only be used with the MPM_PREFORK module and PHP-FPM can only be used with the MPM_EVENT module." : "Het lijkt erop dat de configuratie van PHP en Apache niet compatibel is. Houd er rekening mee dat PHP alleen kan worden gebruikt met de MPM_PREFORK-module en dat PHP-FPM alleen kan worden gebruikt met de MPM_EVENT-module.",
    "Web server setup checks" : "Webserver installatiecontroles",
    "Federated user" : "Gefedereerde gebruiker",
    "Assign participants to rooms" : "Deelnemers aan ruimtes toewijzen",
    "Configure breakout rooms" : "Instellen aparte vergaderruimtes",
    "Number of breakout rooms" : "Aantal Aparte vergaderruimtes",
    "You can create from 1 to 20 breakout rooms." : "Je kan 1 tot 20 aparte vergaderruimtes maken",
    "Assignment method" : "Toewijzingswijze",
    "Automatically assign participants" : "Deelnemers automatisch toewijzen",
    "Manually assign participants" : "Deelnemers handmatig toewijzen",
    "Allow participants to choose" : "Laat deelnemers kiezen",
    "Create rooms" : "Maak vergaderruimtes",
    "Confirm" : "Bevestigen",
    "Create breakout rooms" : "Maak aparte vergaderruimtes",
    "Reset" : "Herstellen",
    "Delete breakout rooms" : "Verwijder aparte vergaderruimtes",
    "Room {roomNumber}" : "Vergaderruimte {roomNumber}",
    "Current breakout rooms and settings will be lost" : "Huidige vergaderruimtes en instellingen gaan verloren",
    "Cancel" : "Annuleren",
    "Unassigned participants" : "Niet-toegewezen deelnemers",
    "Back" : "Terug",
    "Assign" : "Toewijzen",
    "Add participant \"{user}\"" : "Toevoegen deelnemer \"{user}\"",
    "Now" : "Nu",
    "Invalid calendar selected" : "Ongeldige agenda geselecteerd",
    "Invalid start time selected" : "Ongeldige starttijd geselecteerd",
    "Invalid end time selected" : "Ongeldige eindtijd geselecteerd",
    "Invite all users and emails in this conversation" : "Nodig alle gebruikers en e-mailadressen uit in dit gesprek",
    "Meeting created" : "Vergadering gecreëerd",
    "Upcoming meetings" : "Aankomende vergaderingen",
    "Loading …" : "Laden …",
    "No upcoming meetings" : "Geen aankomende vergaderingen",
    "Schedule a meeting" : "Plan een vergadering",
    "Meeting title" : "Vergadering titel",
    "From" : "Van",
    "To" : "Naar",
    "Calendar" : "Agenda",
    "Attendees" : "Deelnemers",
    "Save" : "Opslaan",
    "Search participants" : "Zoek deelnemers",
    "No results" : "Geen resultaten",
    "Done" : "Klaar",
    "Raise hand" : "Hand opsteken",
    "Raise hand (R)" : "Hand omhoog (R)",
    "Lower hand" : "Hand omlaag",
    "Lower hand (R)" : "Hand omlaag (R)",
    "Speaker view" : "Sprekerweergave",
    "Grid view" : "Rasterweergave",
    "Recording consent is required" : "Toestemming voor opname is vereist",
    "This conversation is read-only" : "Dit gesprek is alleen-lezen",
    "Conversation not found or not joined" : "Gesprek niet gevonden of aan deelgenomen",
    "Lobby is still active and you're not a moderator" : "Lobby is nog actief en je bent geen moderator",
    "Connection failed" : "Verbinding mislukt",
    "Reload" : "Herladen",
    "{nickName} raised their hand." : "{nickName} stak zijn/haar hand op",
    "A participant raised their hand." : "Een deelnemer stak zijn/haar hand op.",
    "Collapse stripe" : "Inklappen streep",
    "Expand stripe" : "Uitvouwen streep",
    "Previous page of videos" : "Voorgaande pagina met video's",
    "Next page of videos" : "Volgende pagina met video's",
    "Connecting …" : "Verbinden...",
    "Calling …" : "Bellen ...",
    "Waiting for {user} to join the call" : "Wachten op {user} om deel te nemen aan het gesprek",
    "Waiting for others to join the call …" : "Aan het wachten aan andere deelnemers van de oproep ...",
    "You can invite others in the participant tab of the sidebar" : "Je kunt anderen uitnodigen in de deelnemerstab van de zijbalk",
    "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "Je kunt anderen uitnodigen in het deelnemers tabblad, of deze link met anderen delen om ze uit te nodigen. ",
    "Share this link to invite others!" : "Deel deze link om anderen uit te nodigen!",
    "Copy link" : "Link kopiëren",
    "You are not allowed to enable audio" : "Je bent niet bevoegd om audio te activeren",
    "No audio. Click to select device" : "Geen audio. Klik om apparaat te selecteren",
    "Mute audio" : "Geluid dempen",
    "Mute audio (M)" : "Geluid dempen (M)",
    "Unmute audio" : "Geluid niet meer dempen",
    "Unmute audio (M)" : "Geluid niet meer dempen (M)",
    "None" : "Geen",
    "Access to camera was denied" : "Toegang tot de camera is geweigerd",
    "Error while accessing camera: It is likely in use by another program" : "Fout bij toegang tot camera, vermoedelijk in gebruik bij andere app",
    "Error while accessing camera" : "Fout bij toegang tot camera",
    "You have been muted by a moderator" : "Je bent gedempt door een moderator",
    "Hide presenter video" : "Verberg video van presentator",
    "You are not allowed to enable video" : "Je bent niet geautoriseerd om video in te schakelen",
    "No video. Click to select device" : "Geen video. Klik om apparaat te selecteren",
    "Disable video" : "Video uitschakelen",
    "Disable video (V)" : "Video uitschakelen (V)",
    "Enable video" : "Inschakelen video",
    "Enable video (V)" : "Video inschakelen (V)",
    "Enable video - Your connection will be briefly interrupted when enabling the video for the first time" : "Inschakelen video. Je verbinding wordt kort onderbroken tijdens het voor de eerste keer inschakelen van video,",
    "Enable video (V) - Your connection will be briefly interrupted when enabling the video for the first time" : "Inschakelen video (V) - Je verbinding wordt kort onderbroken tijdens het voor de eerste keer inschakelen van video,",
    "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "Inschakelen video. Je verbinding wordt kort onderbroken tijdens het voor de eerste keer inschakelen van video,",
    "Show presenter" : "Toon presentator",
    "You" : "Jij",
    "Mute" : "Dempen",
    "Muted" : "Gedempt",
    "Show screen" : "Tonen scherm",
    "Stop following" : "Stop met volgen",
    "Connection could not be established …" : "Kon geen verbinding maken ...",
    "Connection was lost and could not be re-established …" : "Verbinding verbroken en kon niet opnieuw verbinden ...",
    "Connection could not be established. Trying again …" : "Kon geen verbinding maken. Opnieuw aan het proberen ...",
    "Connection lost. Trying to reconnect …" : "Verbinding verbroken. Opnieuw aan het proberen ...",
    "Connection problems …" : "Verbindingsproblemen ...",
    "Collapse" : "Inklappen",
    "Expand" : "Uitbreiden",
    "You need to be logged in to upload files" : "Je moet ingelogd zijn om bestanden te uploaden",
    "Drop your files to upload" : "Zet je bestanden hier neer om te uploaden",
    "Conversation messages" : "Gespreksberichten",
    "Scroll to bottom" : "Scroll naar beneden",
    "Post message" : "Plaats bericht",
    "Federated conversation" : "Gefedereerde gesprekken",
    "Public conversation" : "Openbaar gesprek",
    "Favorite" : "Favoriet",
    "Banned users" : "Geblokkeerde gebruikers",
    "Manage the list of banned users in this conversation." : "Beheer de lijst van geblokkeerde gebruikers voor dit gesprek.",
    "Manage bans" : "Beheer blokkeringen",
    "No banned users" : "Geen geblokkeerde gebruikers",
    "Banned by:" : "Geblokkerd door:",
    "Date:" : "Datum:",
    "Note:" : "Notitie:",
    "Hide details" : "Verberg details",
    "Show details" : "Tonen details",
    "Unban" : "Uitsluiten opheffen",
    "Error while updating conversation name" : "Fout bij aanpassen gespreksnaam",
    "Error while updating conversation description" : "Fout tijdens bijwerken gespreksbeschrijving",
    "Enter a name for this conversation" : "Voer een naam in voor dit gesprek",
    "Edit conversation name" : "Bewerk gespreksnaam",
    "Edit conversation description" : "Bewerken gespreksbeschrijving",
    "Enter a description for this conversation" : "Voer een beschrijving in voor dit gesprek",
    "Picture" : "Afbeelding",
    "Disable" : "Uitschakelen",
    "Enable" : "Inschakelen",
    "Breakout rooms" : "Aparte vergaderruimtes",
    "Manage breakout rooms" : "Beheer aparte vergaderruimtes",
    "Set up breakout rooms for this conversation" : "Stel aparte breakout room in voor dit gesprek",
    "Please select a valid PNG or JPG file" : "Selecteer alstublieft een geldig png of jpg bestand",
    "Choose your conversation picture" : "Kies de gespreksafbeelding",
    "Choose" : "Kies",
    "Error setting conversation picture" : "Fout bij instellen gespreksafbeelding",
    "Could not set the conversation picture: {error}" : "Kon de gespreksafbeelding niet instellen: {error}",
    "Error cropping conversation picture" : "Fout bij bijsnijden gespreksafbeelding",
    "Error removing conversation picture" : "Fout bij verwijderen gespreksafbeelding",
    "Set emoji as conversation picture" : "Stel emoji in als gespreksafbeelding",
    "Set background color for conversation picture" : "Stel achtergrondkleur in voor gespreksafbeelding",
    "Upload conversation picture" : "Upload gespreksafbeelding",
    "Choose conversation picture from files" : "Kies gespreksafbeelding via bestanden",
    "Remove conversation picture" : "Verwijder gespreksafbeelding",
    "The file must be a PNG or JPG" : "Het bestand moet een PNG of JPG bestand zijn",
    "Default permissions modified for {conversationName}" : "Standaardmachtigingen aangepast voor {conversationName}",
    "Could not modify default permissions for {conversationName}" : "Kon standaardmachtigingen niet aanpassen voor {conversationName}",
    "Edit the default permissions for participants in this conversation. These settings do not affect moderators." : "Pas de standaardmachtigingen voor deelnemers in dit gesprek aan. Deze instellingen gelden niet voor moderators.",
    "All permissions" : "Alle machtigingen",
    "Participants have permissions to start a call, join a call, enable audio and video, and share screen." : "Deelnemers hebben machtigingen om een gesprek te starten, deel te nemen, audio en camera in te schakelen en het scherm te delen.",
    "Restricted" : "Beperkt",
    "Participants can join calls, but cannot enable audio nor video nor share screen until a moderator manually grants them permissions." : "Deelnemers kunnen deelnemen aan gesprekken, maar kunnen geen audio of camera inschakelen, of hun scherm delen totdat een moderator hen handmatig machtigt.",
    "Advanced permissions" : "Geavanceerde machtigingen",
    "Edit permissions" : "Pas machtigingen aan",
    "Conversation settings" : "Gespreksinstellingen",
    "Basic Info" : "Basisinformatie",
    "Personal" : "Persoonlijk",
    "Moderation" : "Beheer",
    "Setup overview" : "Instellingenoverzicht",
    "Live transcription" : "Live transcriptie",
    "Breakout Rooms" : "Aparte vergaderruimtes",
    "Matterbridge" : "Matterbridge",
    "Bots" : "Bots",
    "Danger zone" : "Gevarenzone",
    "Archive conversation" : "Archiveer gesprek",
    "Archived conversations are hidden from the conversation list by default. However, they will still appear when you search for the conversation name or access a list of archived conversations." : "Gearchiveerde gesprekken zijn standaard verborgen van de gesprekken lijst. Echter, ze zullen nog steeds tevoorschijn komen zodra je zoekt op de naam van het gesprek of de lijst van gearchiveerde gesprekken opent.",
    "Do you really want to leave \"{displayName}\"?" : "Wil je \"{displayName}\" echt verlaten?",
    "You can archive this conversation instead." : "Je kan dit gesprek ook archiveren",
    "Leave conversation" : "Verlaat een gesprek",
    "You need to promote a new moderator before you can leave the conversation" : "Je moet een nieuwe moderator aanwijzen voordat je het gesprek kan verlaten",
    "Delete conversation" : "Verwijder gesprek",
    "Do you really want to delete \"{displayName}\"?" : "Wil je \"{displayName}\" echt verwijderen?",
    "Error while deleting conversation" : "Fout bij verwijderen gesprek",
    "Delete all chat messages" : "Alle chats verwijderen",
    "Do you really want to delete all messages in \"{displayName}\"?" : "Wil je echt alle berichten verwijderen in \"{displayName}\"?",
    "Error while clearing chat history" : "Fout bij het verwijderen van de chathistorie",
    "Be careful, these actions cannot be undone." : "Wees voorzichtig, dit kan niet worden ongedaan gemaakt.",
    "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Zodra een gesprek verlaten is, is een uitnodiging nodig om opnieuw deel te nemen aan het gesprek. Een open gesprek kan te allen tijde hervat worden.",
    "Permanently delete this conversation." : "Verwijder dit gesprek permanent.",
    "Delete chat messages" : "Alle chats verwijderen",
    "Permanently delete all the messages in this conversation." : "Verwijder alle berichten in dit gesprek permanent.",
    "_%n hour_::_%n hours_" : ["%n uur","%n uur"],
    "_%n day_::_%n days_" : ["%n dag","%n dagen"],
    "_%n week_::_%n weeks_" : ["%n week","weken"],
    "Custom expiration time" : "Aangepaste vervalperiode",
    "Message expiration disabled" : "Vervallen bericht uitgeschakeld",
    "Message expiration set: {duration}" : "Vervallen bericht ingesteld: {duration}",
    "Error when trying to set message expiration" : "Fout bij instellen vervallen bericht",
    "Message expiration" : "Vervallen bericht",
    "Chat messages can be expired after a certain time. Note: Files shared in chat will not be deleted for the owner, but will no longer be shared in the conversation." : "Chatberichten kunnen na een bepaalde tijd verlopen. Noot: Bestanden die gedeeld zijn in een chat worden niet verwijderd door de eigenaar, maar worden niet langer gedeeld in het gesprek.",
    "Set message expiration" : "Stel vervallen bericht in",
    "Current message expiration" : "Vervallen huidig bericht",
    "Password copied to clipboard" : "Wachtwoord gekopieerd naar het klembord!",
    "Password could not be copied" : "Wachtwoord kon niet gekopieerd worden",
    "Guest access" : "Gasttoegang",
    "Breakout rooms are not allowed in public conversations." : "Breakout rooms zijn niet toegestaan bij openbare gesprekken",
    "Allow guests to join this conversation via link" : "Sta gasten toe om te deel nemen aan dit gesprek via een link",
    "Password protection" : "Wachtwoordbeveiliging",
    "This conversation is password-protected. Guests need password to join" : "Dit gesprek is beveiligd met een wachtwoord. Gasten hebben een wachtwoord nodig om deel te nemen",
    "Password protection is needed for public conversations" : "Wachtwoordbeveiliging is verplicht voor openbare gesprekken",
    "Set a password" : "Instellen wachtwoord",
    "Change password" : "Wachtwoord wijzigen",
    "Enter new password" : "Voer nieuw wachtwoord in",
    "Save password" : "Wachtwoord opslaan",
    "Copy password" : "Kopieer wachtwoord",
    "Guests are allowed to join this conversation via link" : "Gaten kunnen deelnemen aan dit gesprek via een link",
    "Guests are not allowed to join this conversation" : "Gaten kunnen niet deelnemen aan dit gesprek",
    "Resend invitations" : "Opnieuw verzenden uitnodigingen",
    "This conversation is open to both registered users and users created with the Guests app" : "Het gesprek is toegankelijk voor zowel geregistreerde gebruikers als gebruikers die met de Gasten app aangemaakt zijn",
    "This conversation is open to registered users" : "Dit gesprek is toegankelijk voor geregistreerde gebruikers",
    "This conversation is limited to the current participants" : "Dit gesprek is beperkt tot de huidige deelnemers",
    "You opened the conversation to both registered users and users created with the Guests app" : "Je hebt het gesprek geopend voor geregistreerde gebruikers en voor gebruikers gemaakt in de Gasten app",
    "Error occurred when opening or limiting the conversation" : "Er is een fout opgetreden tijdens het openen of beperken van het gesprek",
    "Open conversation to registered users, showing it in search results" : "Open gesprek voor geregistreerde gebruikers, het zal worden weergegeven in de zoekresultaten",
    "Also open to users created with the Guests app" : "Ook toegankelijk voor gebruikers die met de Gasten app aangemaakt zijn",
    "Open conversation" : "Open gesprek",
    "Invalid language" : "Ongeldige taal",
    "Start time: {date}" : "Starttijd: {date}",
    "Start time has been updated" : "Starttijd bijgewerkt",
    "Error occurred while updating start time" : "Fout bij bijwerken starttijd",
    "Enabling the lobby will remove non-moderators from the ongoing call." : "Inschakelen van de lobby zal niet-moderators uit het lopende gesprek verwijderen.",
    "Enable lobby, restricting the conversation to moderators" : "Lobby inschakelen, gesprek beperken tot moderators",
    "Meeting start time" : "Vergadering starttijd",
    "Start time (optional)" : "Begintijd (optioneel)",
    "Import email participants" : "Importeer e-maildeelnemers",
    "You can import a list of email participants from a CSV file." : "Je kan een lijst van e-maildeelnemers importeren vanuit een CSV-bestand.",
    "Browse poll drafts" : "Blader door peilingconcepten",
    "Error occurred when locking the conversation" : "Er is een fout opgetreden bij het vergrendelen van het gesprek",
    "Error occurred when unlocking the conversation" : "Er is een fout opgetreden bij het ontgrendelen van het gesprek",
    "Lock conversation" : "Gesprek vergrendelen",
    "This will also terminate the ongoing call." : "Hiermee wordt ook het lopende gesprek beëindigd.",
    "Lock the conversation to prevent anyone to post messages or start calls" : "Vergrendel het gesprek om te voorkomen dat iemand berichten kan plaatsen of gesprekken kan starten",
    "Edit" : "Bewerk",
    "More information" : "Meer informatie",
    "Delete" : "Verwijderen",
    "Add new bridged channel to current conversation" : "Een nieuw overbruggingskanaal naar het huidige gesprek",
    "unknown state" : "onbekende staat",
    "running" : "bezig",
    "not running, check Matterbridge log" : "draait niet, controleer Matterbridge logbestand",
    "not running" : "niet bezig",
    "Bridge saved" : "Overbrugging opgeslagen",
    "You can bridge channels from various instant messaging systems with Matterbridge." : "Je kunt kanalen van verschillende chatservices overbruggen met Matterbridge.",
    "More info on Matterbridge" : "Meer info over Matterbridge.",
    "Enable bridge" : "Inschakelen bridge",
    "Show Matterbridge log" : "Toon Matterbridge logbestand",
    "Log content" : "Inhoud logboek",
    "Only moderators are allowed to mention @all" : "Alleen moderators mogen @all vermelden",
    "Mentioning @all has been limited to moderators." : "Het vermelden van @all is beperkt tot moderators",
    "Notifications" : "Meldingen",
    "Notify about calls in this conversation" : "Stuur melding over telefoongesprekken in dit gesprek",
    "Important conversation" : "Belangrijk gesprek",
    "\"Do not disturb\" user status is ignored for important conversations" : "De gebruikersstatus ‘Niet storen’ wordt genegeerd voor belangrijke gesprekken",
    "Sensitive conversation" : "Gevoelig gesprek",
    "Message preview will be disabled in conversation list and notifications" : "Berichtvoorvertoning wordt uitgeschakeld in de gesprekslijst en meldingen",
    "Recording consent is required for calls in this conversation" : "Toestemming voor opname is vereist voor oproepen in dit gesprek",
    "Recording consent is not required for calls in this conversation" : "Toestemming voor opname is niet vereist voor oproepen in dit gesprek",
    "Recording consent requirement was updated" : "Toestemming voor opname status is bijgewerkt",
    "Error occurred while updating recording consent" : "Fout bij bijwerken toestemming opname",
    "Recording Consent" : "Toestemming opname",
    "Recording consent cannot be changed once a call or breakout session has started." : "Toestemming voor opname kan niet worden gewijzigd als een oproep of aparte vergaderruimtes zijn gestart.",
    "Require recording consent before joining call in this conversation" : "Toestemming voor opname vereist voor deelname aan dit gesprek",
    "Recording consent is required for all calls" : "Toestemming voor opname is vereist voor alle gesprekken",
    "SIP dial-in is now possible without PIN requirement" : "Inbellen via SIP is nu mogelijk zonder PIN benodigdheid",
    "SIP dial-in is now enabled" : "SIP inbellen is nu ingeschakeld",
    "SIP dial-in is now disabled" : "SIP inbellen is nu uitgeschakeld",
    "Error occurred when enabling SIP dial-in" : "Fout bij inschakelen SIP inbellen",
    "Error occurred when disabling SIP dial-in" : "Fout bij uitschakelen SIP inbellen",
    "Phone and SIP dial-in" : "Telefoon en SIP inbellen",
    "Enable phone and SIP dial-in" : "Inschakelen telefoon en SIP inbellen",
    "Allow to dial-in without a PIN" : "Inbellen zonder PIN toestaan",
    "With {displayName}" : "Met {displayName}",
    "In {conversation}" : "In {conversation}",
    "Join" : "Deelnemen",
    "View conversation" : "Toon gesprek",
    "Error while creating the conversation" : "Fout bij creëren gesprek",
    "Hello, {displayName}" : "Hallo, {displayName}",
    "Start meeting now" : "Start vergadering nu",
    "Give your meeting a title" : "Geef je vergadering een titel",
    "Create a new conversation" : "Maak een nieuw gesprek",
    "Join open conversations" : "Deelnemen aan open gesprekken",
    "Call a phone number" : "Bel een telefoonnummer",
    "Schedule meetings" : "Plan vergaderingen",
    "You don't have any upcoming meetings" : "Je hebt geen aankomende vergaderingen",
    "Unread mentions" : "Ongelezen vermeldingen",
    "Start a group conversation" : "Start een groepsgesprek",
    "Create conversation" : "Maak gesprek",
    "Enter your name" : "Geef je naam op",
    "Submit name and join" : "Verzend naam en neem deel",
    "Do you already have an account?" : "Heb je al een account?",
    "Log in" : "Aanmelden",
    "Error while verifying uploaded file" : "Fout bij controleren geüpload bestand",
    "Uploaded file is verified" : "Geüpload bestand is gecontroleerd",
    "Participants added successfully" : "Deelnemers succesvol toegevoegd",
    "Error while adding participants" : "Fout bij toevoegen deelnemers",
    "Import a file" : "Importeer een bestand",
    "Send invitations" : "Stuur uitnodigingen",
    "_%n invalid email_::_%n invalid emails_" : ["%n ongeldige e-mail","%n ongeldige e-mails"],
    "_%n email is already imported or a duplicate_::_%n emails are already imported or duplicates_" : ["%n  e-mail al geimporteerd of duplicaat","%n e-mails al geimporteerd of duplicaten"],
    "_%n invitation can be sent_::_%n invitations can be sent_" : ["%n uitnodiging kan verzonden worden","%n uitnodigingen kunnen verzonden worden"],
    "An error occurred while calling a phone number" : "Er trad een fout op bij bellen van een telefoonnummer",
    "Phone number could not be called: {error}" : "Telefoonnummer kon niet bereikt worden:  {error} ",
    "Phone number could not be called" : "Telefoonnummer kon niet bereikt worden",
    "Search participants or phone numbers" : "Zoek deelnemers of telefoonnummers",
    "Creating the conversation …" : "Het gesprek maken ...",
    "Mark as read" : "Markeren als gelezen",
    "Mark as unread" : "Markeren als ongelezen",
    "Remove from favorites" : "Verwijderen uit favorieten",
    "Add to favorites" : "Toevoegen aan favorieten",
    "Unarchive conversation" : "Dearchiveer gesprek",
    "You need to promote a new moderator before you can leave the conversation." : "Je moet een nieuwe moderator promoveren voordat je het gesprek kunt verlaten.",
    "Conversation actions" : "Gespreksacties",
    "Notify about calls" : "Melden inkomende gesprekken",
    "Pending invitations" : "Wachtende uitnodigingen",
    "Join conversations from other servers" : "Neem deel aan gesprekken van andere servers",
    "From {user} at {remoteServer}" : "Van {user} op{remoteServer}",
    "Decline invitation" : "Uitnodiging afwijzen",
    "Accept invitation" : "Uitnodiging accepteren",
    "No pending invitations" : "Geen wachtende uitnodigingen",
    "Home" : "Startpagina",
    "Unread" : "Ongelezen",
    "Meetings" : "Vergaderingen",
    "Alphabetically" : "Alfabetisch",
    "No matches found" : "Geen overeenkomsten gevonden.",
    "No conversations found" : "Geen gesprekken gevonden",
    "You have no archived conversations." : "Je hebt geen gearchiveerde gesprekken.",
    "You have no unread mentions." : "Je hebt geen ongelezen vermeldingen.",
    "You have no unread messages." : "Je hebt geen ongelezen berichten..",
    "An error occurred while performing the search" : "Er trad een fout op bij uitvoeren van de zoekopdracht",
    "Conversation list" : "Gesprekkenlijst",
    "Filter conversations by" : "Filter gesprekken op",
    "Unread messages" : "Ongelezen berichten",
    "Meeting conversations" : "Vergadering gesprekken",
    "Clear filters" : "Wis filters",
    "New personal note" : "Nieuwe persoonlijke notitie",
    "Back to conversations" : "Terug naar gesprekken",
    "Archived conversations" : "Gearchiveerde gesprekken",
    "Threads" : "Draden",
    "Clear filter" : "Filter leegmaken",
    "App settings" : "App instellingen",
    "Users" : "Gebruikers",
    "Groups" : "Groepen",
    "Teams" : "Teams",
    "New private conversation" : "Nieuw privégesprek",
    "Other sources" : "Andere bronnen",
    "Open conversations" : "Open gesprekken",
    "No search results" : "Geen zoekresultaten",
    "Users, groups and teams" : "Gebruikers, groepen en teams",
    "Users and groups" : "Gebruikers en groepen",
    "Users and teams" : "Gebruikers en groepen",
    "Groups and teams" : "Groepen en teams",
    "New group conversation" : "Nieuw groepsgesprek",
    "The meeting will start soon" : "De vergadering begint binnenkort",
    "This meeting is scheduled for {startTime}" : "Deze vergadering is gepland voor {startTime}",
    "You are currently waiting in the lobby" : "Je wacht nu in de lobby",
    "Select microphone" : "Selecteer microfoon",
    "No microphone available" : "Geen microfoon aanwezig",
    "Select camera" : "Selecteer camera",
    "No camera available" : "Geen camera aanwezig",
    "Select a device" : "Selecteer een apparaat",
    "Playing …" : "Afspelen...",
    "Test speakers" : "Test speakers",
    "Test" : "Test",
    "Devices" : "Apparaten",
    "Backgrounds" : "Achtergronden",
    "No audio" : "Geen geluid",
    "No camera" : "Geen camera",
    "Display video as you will see it (mirrored)" : "Toon video zoals jij het zal zien (gespiegeld)",
    "Display video as others will see it" : "Toon video zoals anderen het zullen zien",
    "Calls are not supported in your browser" : "Oproepen worden niet ondersteund in je browser",
    "Access to microphone is only possible with HTTPS" : "Toegang tot microfoon is alleen mogelijk met HTTPS",
    "Access to microphone was denied" : "Toegang tot de microfoon is geweigerd",
    "Error while accessing microphone" : "Fout bij toegang tot microfoon",
    "Access to camera is only possible with HTTPS" : "Toegang tot de camera is alleen mogelijk met HTTPS",
    "The call is being recorded." : "Het gesprek wordt opgenomen",
    "The call might be recorded." : "Het gesprek kan opgenomen worden.",
    "The recording might include your voice, video from camera, and screen share. Your consent is required before joining the call." : "De opname kan je stem, video van je camera en schermdelen bevatten. Je toestemming is nodig voorafgaand aan deelname aan het gesprek. ",
    "Give consent to the recording of this call" : "Geef toestemming voor opname van dit gesprek",
    "Start recording immediately with the call" : "Start opname meteen met het gesprek",
    "Apply settings" : "Instellingen toepassen",
    "Select virtual office background" : "Selecteer virtuele kantoorachtegrond",
    "Select virtual home background" : "Selecteer virtuele thuis achtergrond",
    "Select virtual abstract background" : "Selecteer virtuele abstracte achtergrond",
    "Select virtual beach background" : "Selecteer virtuele strand achtergrond",
    "Select virtual park background" : "Selecteer virtuele park achtergrond",
    "Select virtual theater background" : "Selecteer virtuele theater achtergrond",
    "Select virtual library background" : "Selecteer virtuele bibliotheek achtergrond",
    "Select virtual space station background" : "Selecteer virtuele ruimtestation achtergrond",
    "Error while uploading the file" : "Fout bij uploaden van het bestand",
    "Select a file" : "Selecteer een bestand",
    "Invalid path selected" : "Ongeldig pad geselecteerd",
    "Select virtual background from file {fileName}" : "Selecteer virtuele achtergrond vanuit bestand {fileName}",
    "Blur" : "Vervagen",
    "Upload" : "Upload",
    "Files" : "Bestanden",
    "(edited)" : "(bewerkt)",
    "The message has expired or has been deleted" : "Bericht is verlopen of verwijderd.",
    "Cancel quote" : "Annuleer citaat",
    "24 hours" : "24 uur",
    "7 days" : "7 dagen",
    "Until unpin" : "Tot ontpint",
    "Edited by {actor}" : "Bewerkt door {actor}",
    "Message text copied to clipboard" : "Berichttekst naar klembord gekopieerd",
    "Message text could not be copied" : "Berichttekst kon niet gekopieerd worden",
    "Message forwarded to \"Note to self\"" : "Bericht doorgestuurd naar \"Notitie voor mezelf\"",
    "Error while forwarding message to \"Note to self\"" : "Fout bij doorsturen bericht naar \"Notitie voor mezelf\"",
    "A reminder was successfully removed" : "Een herinnering succesvol verwijderd",
    "Error occurred when removing a reminder" : "Fout opgetreden bij verwijderen herinnering",
    "A reminder was successfully set at {datetime}" : "Een herinnering succesvol ingesteld op {datetime}",
    "Error occurred when creating a reminder" : "Fout opgetreden bij maken herinnering",
    "Add a reaction to this message" : "Een reactie toevoegen aan dit bericht",
    "Reply" : "Antwoord",
    "More actions" : "Meer acties",
    "Set reminder" : "Herinnering instellen",
    "Pin message" : "Pin bericht",
    "Unpin message" : "Ontpin bericht",
    "Reply privately" : "Antwoord privé",
    "Edit message" : "Bewerk bericht",
    "Copy message link" : "Kopiëren berichtlink",
    "Go to file" : "Ga naar bestand",
    "Download file" : "Downloaden bestand",
    "Go to thread" : "Ga naar draad",
    "Forward message" : "Bericht doorsturen",
    "Translate" : "Vertaal",
    "Set custom reminder" : "Aangepaste herinnering instellen",
    "Close reactions menu" : "Reactie-menu sluiten",
    "React with {emoji}" : "Reageer met {emoji}",
    "React with another emoji" : "Reageer met een andere emoji",
    "Choose a conversation to forward the selected message." : "Kies een gesprek om het geselecteerde bericht aan door te sturen.",
    "Error while forwarding message" : "Fout bij doorsturen bericht",
    "The message has been forwarded to {selectedConversationName}" : "Het bericht is doorgestuurd naar {selectedConversationName}",
    "Dismiss" : "Weigeren",
    "Go to conversation" : "Ga naar gesprek",
    "Detect language" : "Detecteer taal",
    "The message could not be translated" : "Het bericht kon niet vertaald worden",
    "Translation copied to clipboard" : "Vertaling gekopieerd naar klembord",
    "Translation could not be copied" : "Vertaling kon niet gekopieerd worden",
    "Translate message" : "Vertaal bericht",
    "Source language to translate from" : "Brontaal om vanuit te vertalen",
    "Translate from" : "Vertaal vanuit",
    "Target language to translate into" : "Doeltaal om naar te vertalen",
    "Translate to" : "Vertaal naar",
    "Translating" : "Vertalen",
    "Copy translated text" : "Kopieer vertaalde tekst",
    "Send now" : "Nu versturen",
    "Message read by everyone who shares their reading status" : "Bericht gelezen door iedereen die de eigen leesstatus deelt",
    "Message sent" : "Bericht verstuurd",
    "Sent without notification" : "Verstuurd zonder melding",
    "Deleting message" : "Bericht aan het verwijderen",
    "Message deleted successfully" : "Bericht succesvol verwijderd",
    "Message could not be deleted because it is too old" : "Bericht kon niet worden verwijderd omdat het te oud is",
    "Only normal chat messages can be deleted" : "Alleen normale chatberichten kunnen worden verwijderd",
    "An error occurred while deleting the message" : "Er trad een fout op bij het verwijderen van het bericht",
    "Pinned" : "Gepind",
    "Your browser does not support playing audio files" : "Je browser heeft geen ondersteuning voor afspelen audiobestanden.",
    "Contact" : "Contactpersoon",
    "{stack} in {board}" : "{stack} in {board}",
    "Deck Card" : "Deck kaart",
    "Remove {fileName}" : "Verwijderen {fileName}",
    "Open this location in OpenStreetMap" : "Open deze locatie in Openstreetmap",
    "_%n reply_::_%n replies_" : ["%n antwoord","%n antwoordt"],
    "Sending message" : "Versturen bericht",
    "Failed to send the message. Click to try again" : "Versturen bericht is mislukt, tik om het opnieuw te proberen.",
    "Not enough free space to upload file" : "Onvoldoende vrije ruimte voor opslaan bestand",
    "You cannot send messages to this conversation at the moment" : "Je kunt nu geen berichten versturen binnen dit gesprek",
    "Could not update the message" : "Kon het bericht niet bijwerken",
    "You voted" : "Je hebt gestemd",
    "_%n vote_::_%n votes_" : ["%n stem","%n stemmen"],
    "See results" : "Zie resultaten",
    "Reactions" : "Reacties",
    "No permission to post reactions in this conversation" : "Geen toestemming om reacties te plaatsen in dit gesprek",
    "Show or collapse system messages" : "Uit- of inklappen systeemberichten",
    "No messages" : "Geen berichten",
    "All messages have expired or have been deleted." : "Alle berichten zijn verlopen of zijn verwijderd.",
    "Unpin" : "Losmaken",
    "Cancel search" : "Zoekopdracht annuleren",
    "Add a phone number" : "Voeg een telefoonnummer toe",
    "Error: A password is required to create the conversation." : "Fout: Een wachtwoord is vereist om het gesprek te maken.",
    "All set, the conversation \"{conversationName}\" was created." : "Klaar, het gesprek \"{conversationName}\" is aangemaakt.",
    "Create a new group conversation" : "Maak een nieuw groepsgesprek",
    "Add participants" : "Deelnemers toevoegen",
    "Maximum length exceeded ({maxlength} characters)" : "Maximale lengte overschreden ({maxlength}tekens)",
    "Conversation visibility" : "Zichtbaarheid gesprek",
    "Allow guests to join via link" : "Sta gasten toe om deel te nemen via een link",
    "Enter password" : "Invullen wachtwoord",
    "This conversation has been locked" : "Het gesprek is vergrendeld",
    "No permission to post messages in this conversation" : "Geen machtiging om berichten in dit gesprek te plaatsen",
    "Joining conversation …" : "Deelnemen aan gesprek ...",
    "Write a message without notification" : "Schrijf een bericht zonder melding",
    "Create a thread" : "Creëer een draad",
    "Send message" : "Verstuur bericht",
    "Send without notification" : "Versturen zonder melding",
    "The participant will not be notified about new messages" : "De deelnemer zal niet ingelicht worden over nieuwe berichten",
    "Participants will not be notified about new messages" : "Deelnemers zullen niet ingelicht worden over nieuwe berichten",
    "The message could not be edited" : "Het bericht kon niet bewerkt worden",
    "File to share" : "Bestand om te delen",
    "File upload is not available in this conversation" : "Bestandsupload is niet beschikbaar in dit gesprek",
    "Add emoji" : "Emoji toevoegen",
    "Adding a mention will only notify users who did not read the message." : "Het toevoegen van een vermelding zal alleen de gebruikers berichten die het bericht nog niet gelezen hebben.",
    "Thread title" : "Draad-titel",
    "Send later" : "Verstuur later",
    "Cancel editing" : "Annuleer bewerken",
    "{user} is out of office and might not respond." : "{user} is afwezig en zal mogelijk niet antwoorden",
    "Absence period: {startDate} - {endDate}" : "Afwezigheidsperiode:  {startDate} - {endDate}",
    "Share from Files" : "Delen vanuit Bestanden",
    "Share files to the conversation" : "Deel bestanden binnen het gesprek",
    "Upload from device" : "Uploaden vanaf apparaat",
    "Create new poll" : "Nieuwe peiling aanmaken",
    "Smart picker" : "Smart Picker",
    "Record voice message" : "Opnemen gesproken bericht",
    "End recording and send" : "Beëindigen opname en versturen",
    "Dismiss recording" : "Opname sluiten",
    "Access to the microphone was denied" : "Toegang tot de microfoon is geweigerd",
    "Microphone either not available or disabled in settings" : "Microfoon niet beschikbaar of uitgeschakeld in instellingen",
    "Error while recording audio" : "Fout tijdens opnemen audio",
    "Voice message {time} ({conversation})" : "Spraak bericht {time} ({conversation})",
    "Summary is AI generated and might contain mistakes" : "Samenvatting is gegenereerd via AI en kan fouten bevatten",
    "Error occurred during a summary generation" : "Er trad een fout op tijdens genereren samenvatting",
    "New file" : "Nieuw bestand",
    "Blank" : "Blanco",
    "Error while creating file" : "Fout bij maken bestand",
    "Create and share a new file" : "Maak en deel een nieuw bestand",
    "Name of the new file" : "Naam van het nieuwe bestand",
    "Create file" : "Maak bestand",
    "Someone is typing …" : "Iemand aan het typen ...",
    "{user1} is typing …" : "{user1} aan het typen …",
    "{user1} and {user2} are typing …" : "{user1} en {user2} aan het typen …",
    "{user1}, {user2} and {user3} are typing …" : "{user1}, {user2} en {user3} aan het typen …",
    "Add more files" : "Voeg meer bestanden toe",
    "Send" : "Verzend",
    "In this conversation <strong>{user}</strong> can:" : "In dit gesprek kan <strong>{user}</strong>:",
    "Edit default permissions for participants in <strong>{conversationName}</strong>" : "Pas standaardmachtigingen voor deelnemers in <strong>{conversationName}</strong> aan",
    "Start a call" : "Start een telefoongesprek",
    "Skip the lobby" : "Skip de lobby",
    "Can post messages and reactions" : "Kan berichten en reacties plaatsen",
    "Enable the microphone" : "Schakel microfoon in",
    "Enable the camera" : "Camera aan zetten",
    "Share the screen" : "Deel jouw scherm",
    "Update permissions" : "Machtigingen bijwerken",
    "Updating permissions" : "Update machtigingen",
    "There is no poll drafts yet saved for this conversation" : "Er is nog geen concept poll opgeslagen voor dit gesprek",
    "Create poll" : "Peiling aanmaken",
    "Question" : "Vraag",
    "Ask a question" : "Stel een vraag",
    "Import draft from file" : "Importeer concept vanuit een bestand",
    "Answers" : "Antwoorden",
    "Settings" : "Instellingen",
    "Anonymous poll" : "Anonieme peiling",
    "Multiple answers" : "Meerdere antwoorden",
    "End poll" : "Peiling beëindigen",
    "Results" : "Resultaten",
    "Send a message to \"{roomName}\"" : "Stuur een bericht naar \"{roomName}\"",
    "Hide list of participants" : "Verberg lijst met deelnemers",
    "Show list of participants" : "Toon lijst met deelnemers",
    "Assistance requested in {roomName}" : "Assistentie gevraagd in {roomName}",
    "The message was sent to \"{roomName}\"" : "Het bericht is verstuurd naar \"{roomName}\"",
    "Send message to room" : "Stuur bericht naar ruimte",
    "Back to main room" : "Terug naar hoofdruimte",
    "Back to your room" : "Terug naar je ruimte",
    "Message all rooms" : "Bericht alle ruimtes",
    "Start session" : "Start sessie",
    "Start a call before you start a breakout room session" : "Start een oproep voordat je vergaderruimtessessie start",
    "Stop session" : "Stop sessie",
    "The message was sent to all breakout rooms" : "Het bericht is verstuurd naar alle ruimtes",
    "Send a message to all breakout rooms" : "Stuur een bericht naar alle ruimtes",
    "Breakout rooms are not started" : "Aparte vergaderruimtes zijn niet gestart",
    "Disable lobby" : "Lobby uitschakelen",
    "Settings for participant \"{user}\"" : "Instellingen voor deelnemer \"{user}\"",
    "Participant \"{user}\"" : "Deelnemer \"{user}\"",
    "moderator" : "moderator",
    "bot" : "bot",
    "guest" : "gast",
    "Ringing …" : "Bellen ...",
    "Call rejected" : "Gesprek afgewezen",
    "{time} talking …" : "{time} bellend ...",
    "{time} talking time" : "{time} beltijd",
    "Raised their hand" : "Hand opgestoken",
    "Joined with video" : "Deelname via video",
    "Joined via phone" : "Deelname via telefoon",
    "Joined with audio" : "Deelname via audio",
    "The text must be less than or equal to {maxLength} characters long. Your current text is {charactersCount} characters long." : "De beschrijving moet kleiner zijn dan of gelijk zijn aan {maxLength} tekens. Je tekst is nu {charactersCount} tekens lang.",
    "Remove group and members" : "Verwijderen groep en leden",
    "Remove team and members" : "Verwijderen team en leden",
    "Remove participant" : "Verwijder deelnemer",
    "Do you really want to remove group \"{displayName}\" and its members from this conversation?" : "Wilt je groep \"{displayName}\" en de leden ervan echt uit dit gesprek verwijderen?",
    "Do you really want to remove team \"{displayName}\" and its members from this conversation?" : "Wilt je team \"{displayName}\" en zijn leden echt uit dit gesprek verwijderen?",
    "Do you really want to remove {displayName} from this conversation?" : "Wilt je {displayName} echt uit dit gesprek verwijderen?",
    "Notification was sent to {displayName}" : "Melding was verstuurd naar {displayName}",
    "Could not send notification to {displayName}" : "Kon geen melding versturen naar {displayName}",
    "Permissions granted to {displayName}" : "Machtiginen gegeven aan {displayName}",
    "Could not modify permissions for {displayName}" : "Kon machtigingen voor {displayName} niet aanpassen",
    "Permissions removed for {displayName}" : "Machtigingen verwijderd voor {displayName}",
    "Permissions set to default for {displayName}" : "Machtigingen naar standaard hersteld voor {displayName}",
    "in the lobby" : "in de lobby",
    "Hang up phone" : "Telefoon ophangen",
    "Move back to lobby" : "Verplaats terug naar lobby",
    "Move to conversation" : "Verplaats naar gesprek",
    "Dial-in PIN" : "Inbel PIN",
    "Demote from moderator" : "Degradeer van moderator",
    "Promote to moderator" : "Promoveer tot moderator",
    "Resend invitation" : "Opnieuw verzenden uitnodiging",
    "Send call notification" : "Verstuur gespreksmelding",
    "Dial out phone number" : "Bel een telefoonnummer",
    "Resume call for phone number" : "Hervat gesprek voor telefoonnummer",
    "Put phone number on hold" : "Plaats telefoonummer in de wacht",
    "Unmute phone number" : "Dempen telefoonnummer opheffen",
    "Mute phone number" : "Demp telefoonnummer",
    "Copy phone number" : "Kopieer telefoonnummer",
    "Reset custom permissions" : "Herstel aangepaste machtigingen",
    "Grant all permissions" : "Geef alle machtigingen",
    "Remove all permissions" : "Verwijder alle machtigingen",
    "Also ban from this conversation" : "Blokkeer ook voor dit gesprek",
    "Internal note (reason to ban)" : "Interne notitie ( reden voor blokkeren)",
    "Remove" : "Verwijderen",
    "Permissions modified for {displayName}" : "Machtigingen aangepast voor {displayName}",
    "Add users or groups" : "Toevoegen gebruikers of groepen",
    "Add users" : "Toevoegen gebruikers",
    "Add groups" : "Toevoegen groepen",
    "Add teams" : "Teams toevoegen",
    "Add other sources" : "Toevoegen andere bronnen",
    "Add emails" : "Toevoegen e-mailadressen",
    "Integrations" : "Integraties",
    "Add federated users" : "Voeg gefedereerde gebruikers toe",
    "Searching …" : "Zoeken ...",
    "Search for more users" : "Zoek naar meer gebruikers",
    "Search or add participants" : "Zoeken naar of toevoegen deelnemers",
    "Invitation was sent to {actorId}" : "Uitnodig was verstuurd naar {actorId}",
    "An error occurred while adding the participants" : "Er trad een fout op bij het toevoegen van deelnemers",
    "Participants" : "Deelnemers",
    "Participants ({count})" : "Deelnemers ({count})",
    "Open chat" : "Openen gesprek",
    "You have new unread messages in the chat." : "Je hebt nieuwe ongelezen berichten in de chat.",
    "You have been mentioned in the chat." : "Je werd vermeld in een chat.",
    "Chat" : "Chat",
    "Details" : "Details",
    "Shared items" : "Gedeelde objecten",
    "No results found" : "Geen resultaten gevonden",
    "Load more results" : "Laad meer resultaten",
    "Recent threads" : "Recente draden",
    "Projects" : "Projecten",
    "No shared items" : "Geen gedeelde objecten",
    "Thread notifications" : "Draad-berichten",
    "{actor}: {lastMessage}" : "{actor}: {lastMessage}",
    "Link to a conversation" : "Verbind met een gesprek",
    "Search conversations or users" : "Zoek in gesprekken of gebruikers",
    "Select conversation" : "Selecteer een gesprek",
    "Display name: {name}" : "Weergavenaam: {name}",
    "Edit display name" : "Weergavenaam bewerken",
    "Display name (required)" : "Weergavenaam (verplicht)",
    "Save name" : "Naam opslaan",
    "Error while saving sounds setting" : "Fout bij opslaan geluidsinstellingen",
    "Play sounds when participants join or leave a call" : "Geluid afspelen wanneer deelnemers meedoen met een gesprek of het verlaten",
    "Notification settings" : "Meldingsinstellingen",
    "Invalid language ({languageId})" : "Ongeldige taal ({languageId})",
    "Default language" : "Standaardtaal",
    "Select location for attachments" : "Selecteer locatie voor bijlagen",
    "Error while setting attachment folder" : "Fout bij instellen map voor bijlagen",
    "Error while setting read status privacy" : "Fout bij instellen lees-status privacy",
    "Privacy" : "Privacy",
    "Attachments folder" : "Bijlagemap",
    "Search" : "Zoeken",
    "Focus the chat input" : "Focus op de chat invoer",
    "Unfocus the chat input to use shortcuts" : "Verwijder focus op de chat invoer om sneltoetsen te kunnen gebruiken",
    "Shortcuts while in a call" : "Snelkoppelingen tijdens een oproep",
    "Camera on and off" : "Camera aan en uit",
    "Microphone on and off" : "Microfoon aan en uit",
    "Raise or lower hand" : "Hand omhoog of omlaag",
    "Push to talk or push to mute" : "Tik om te praten of tik om te dempen",
    "Start call silently" : "Start gesprek stil",
    "Start call" : "Start oproep",
    "End call" : "Beëindig gesprek",
    "The server was updated, you cannot start or join a call." : "De server heeft een update gehad, je kan geen oproep starten of er aan deelnemen",
    "You will be able to join the call only after a moderator starts it." : "Je kunt pas aan de oproep deelnemen als een moderator die gestart heeft.",
    "End call for everyone" : "Beëindig gesprek voor iedereen",
    "Recording" : "Opnemen",
    "The call has been running for one hour." : "Dit gesprek is actief gedurende een uur",
    "Cancel recording start" : "Annulleer start opname",
    "Stop recording" : "Beëindig opname",
    "You are not allowed to enable screensharing" : "Je bent niet bevoegd om schermdeling in te schakelen",
    "No screensharing" : "Geen schermdelen",
    "Screensharing options" : "Schermdelen opties",
    "Enable screensharing" : "Inschakelen schermdelen",
    "Bad sent video and screen quality." : "Slechte verzonden video- en schermkwaliteit.",
    "Bad sent screen quality." : "Slechte verzonden schermkwaliteit.",
    "Bad sent video quality." : "Slechte verzonden videokwaliteit.",
    "Bad sent audio, video and screen quality." : "Slechte verzonden audio-, video- en schermkwaliteit.",
    "Bad sent audio and screen quality." : "Slecht verzonden audio en schermkwaliteit.",
    "Bad sent audio and video quality." : "Slechte verzonden audio- en videokwaliteit.",
    "Bad sent audio quality." : "Slechte verzonden audiokwaliteit.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable the background blur or your video while doing a screen share." : "Je internetverbinding of computer zijn bezig en andere deelnemers zijn mogelijk niet in staat je scherm te zien. Probeer de achtergrondvervaging of je camera uit te schakelen om de situatie te verbeteren terwijl je je scherm deelt.",
    "Disable background blur" : "Schakel vervaagde achtergrond uit",
    "Your internet connection or computer are busy and other participants might be unable to see your screen. To improve the situation try to disable your video while doing a screenshare." : "Jouw internetverbinding of computer is overbelast en andere deelnemers kunnen jou scherm mogelijk niet zien. Om de situatie te verbeteren kun je jouw video uitzetten terwijl je screenshare gebruikt.",
    "Your internet connection or computer are busy and other participants might be unable to see your screen." : "Je internetverbinding of computer is overbelast en andere deelnemers kunnen je scherm mogelijk niet zien.",
    "Your internet connection or computer are busy and other participants might be unable to see you." : "Je internetverbinding of computer is overbelast en andere deelnemers kunnen je mogelijk niet zien.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video while doing a screenshare." : "Je internetverbinding of computer zijn bezig en andere deelnemers zijn mogelijk niet in staat je te verstaan en je te zien. Probeer de achtergrondvervaging of je camera uit te schakelen om de situatie te verbeteren terwijl je je scherm deelt.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video while doing a screenshare." : "Je internetverbinding of computer is overbelast en andere deelnemers kunnen je mogelijk niet verstaan ​​of zien. Om de situatie te verbeteren, kun je proberen je video uit te schakelen terwijl je een schermafbeelding uitvoert.",
    "Your internet connection or computer are busy and other participants might be unable to understand you and see your screen. To improve the situation try to disable your screenshare." : "Je internetverbinding of computer zijn bezig en andere deelnemers zijn mogelijk niet in staat je te verstaan en je scherm te zien. Probeer je schermdeling uit te schakelen om de situatie te verbeteren.",
    "Disable screenshare" : "Schakel Scherm-delen uit",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable the background blur or your video." : "Je internetverbinding of computer zijn bezig en andere deelnemers zijn mogelijk niet in staat je te verstaan en zien. Probeer de achtergrondvervaging of je camera uit te schakelen om de situatie te verbeteren.",
    "Your internet connection or computer are busy and other participants might be unable to understand and see you. To improve the situation try to disable your video." : "Je internetverbinding of computer is overbelast en andere deelnemers kunnen je mogelijk niet verstaan ​​of zien. Probeer je video uit te schakelen om de situatie te verbeteren.",
    "Your internet connection or computer are busy and other participants might be unable to understand you." : "Je internetverbinding of computer is overbelast en andere deelnemers kunnen je misschien niet verstaan.",
    "Screen sharing is not supported by your browser." : "Schermdelen wordt niet ondersteund door je browser.",
    "Screen sharing requires the page to be loaded through HTTPS." : "Schermdelen vereist het over HTTPS laden van de pagina.",
    "Screensharing requires the page to be loaded through HTTPS." : "Schermdelen vereist het over HTTPS laden van de pagina.",
    "An error occurred while starting screensharing." : "Er trad een fout op bij starten schermdelen.",
    "Show your screen" : "Mijn scherm weergeven",
    "Stop screensharing" : "Stop schermdelen",
    "Mute others" : "Anderen dempen",
    "Start recording" : "Begin opname",
    "Remove participant {name}" : "Deelnemer {name} verwijderen",
    "Delete now" : "Verwijder nu",
    "Keep" : "Behouden",
    "Select a region" : "Selecteer een regie",
    "Local time: {time}" : "Lokale tijd: {time}",
    "Search …" : "Zoeken ...",
    "Message without mention" : "Bericht zonder vermelding",
    "Mention myself" : "Vermeld mezelf",
    "The conversation does not exist" : "Het gesprek bestaat niet",
    "Join a conversation or start a new one!" : "Doe mee met een discussie, of start een nieuwe!",
    "Duplicate session" : "Dubbele sessie",
    "Join a conversation or start a new one" : "Doe mee met een discussie, of start een nieuwe",
    "Nextcloud URL" : "Nextcloud URL",
    "Nextcloud user" : "Nextcloud gebruiker",
    "User password" : "Gebruiker wachtwoord",
    "Talk conversation" : "Talk gesprek",
    "Skip TLS verification" : "TLS verificatie overslaan",
    "Matrix server URL" : "Matrix server URL",
    "User" : "Gebruiker",
    "Matrix channel" : "Matrix kanaal",
    "Mattermost server URL" : "Mattermost server URL",
    "Mattermost user" : "Mattermost gebruiker",
    "Team name" : "Team naam",
    "Channel name" : "Kanaal naam",
    "Rocket.Chat server URL" : "Rocket.Chat server URL",
    "User name or email address" : "Gebruikersnaam of e-mailadres",
    "Rocket.Chat channel" : "Rocket.Chat kanaal",
    "Zulip server URL" : "Zulip server URL",
    "Bot user name" : "Bot gebruikersnaam",
    "Bot API key" : "Bot API-sleutel",
    "Zulip channel" : "Zulip kanaal",
    "API token" : "API token",
    "Slack channel" : "Slack kanaal",
    "Server ID or name" : "Server ID of naam",
    "Channel" : "Kanaal",
    "Login" : "Inloggen",
    "Chat ID" : "Chat ID",
    "IRC server URL (e.g. chat.freenode.net:6667)" : "IRC server URL (bijv. chat.freenode.net:6667)",
    "Nickname" : "Roepnaam",
    "Connection password" : "Verbinding wachtwoord",
    "IRC channel" : "IRC kanaal",
    "Channel password" : "Kanaal password",
    "NickServ nickname" : "NickServ nickname",
    "NickServ password" : "NickServ wachtwoord",
    "Use TLS" : "Gebruik TLS",
    "Use SASL" : "Gebruik SASL",
    "Tenant ID" : "Tenant ID",
    "Client ID" : "Client ID",
    "Team ID" : "Team ID",
    "Thread ID" : "Draad ID",
    "XMPP/Jabber server URL" : "XMPP/Jabber server URL",
    "MUC server URL" : "MUC server URL",
    "Jabber ID" : "Jabber ID",
    "Media" : "Media",
    "Polls" : "Peilingen",
    "Deck cards" : "Deck kaarten",
    "Voice messages" : "Voice berichten",
    "Locations" : "Locaties",
    "Audio" : "Geluid",
    "Show all media" : "Toon alle media",
    "Show all files" : "Toon alle bestanden",
    "Show all deck cards" : "Toon alle Deck kaarten",
    "Show all voice messages" : "Toon alle voice berichten",
    "Show all locations" : "Toon alle locaties",
    "Show all audio" : "Toon alle audio",
    "Show all other" : "Toon alle anderen",
    "Follow conversation settings" : "Volg conversatie instellingen",
    "Group" : "Groep",
    "Team" : "Team",
    "You promoted {user0} and {user1} to moderators" : "Je promoveerde {user0} en {user1} to moderators",
    "_You promoted {user0}, {user1} and %n more participant to moderators_::_You promoted {user0}, {user1} and %n more participants to moderators_" : ["Je promoveerde{user0}, {user1} en %n meer deelnemer to moderators","Je promoveerde {user0}, {user1} en %n meer deelnemers tot moderators"],
    "An administrator promoted you and {user0} to moderators" : "Een beheerder promoveerde jou en {user0} tot moderators",
    "{actor} promoted you and {user0} to moderators" : "{actor} promoveerde jou en {user0} tot moderators",
    "You:" : "Jij:",
    "You: {lastMessage}" : "Jij: {lastMessage}",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "The server was updated." : "De server heeft een update gehad.",
    "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Je probeert deel te nemen aan een gesprek terwijl je een actieve sessie hebt in een ander venster of apparaat. Dit wordt momenteel niet ondersteund door Nextcloud Talk. Wat wil je doen?",
    "Leave this page" : "Verlaat deze pagina",
    "Join here" : "Meld u hier aan",
    "An error occurred while posting deck card to conversation" : "Een fout heeft plaatsgevonden bij het plaatsen van de deck kaart in het gesprek",
    "Post to a conversation" : "Publiceer in een gesprek",
    "Post to conversation" : "Publiceren naar gesprek",
    "The recording failed. Please contact your administrator." : "The opname is mislukt. Neem contact op met je beheerder.",
    "An error occurred while posting location to conversation" : "Een fout heeft plaatsgevonden bij het versturen van de locatie naar het gesprek",
    "Share to a conversation" : "Deel naar een gesprek",
    "Share to conversation" : "Deel naar gesprek",
    "Error while clearing conversation history" : "Fout bij het verwijderen van de gespreksgeschiedenis",
    "Error occurred while allowing guests" : "Fout bij toelaten gasten",
    "Error occurred while disallowing guests" : "Fout bij toegang ontzeggen voor gasten",
    "Error occurred when restricting the conversation to moderator" : "Er is een fout opgetreden bij het beperken van het gesprek tot moderator",
    "Error occurred when opening the conversation to everyone" : "Er is een fout opgetreden bij het openen van het gesprek voor iedereen",
    "Conversation password has been saved" : "Gesprekswachtwoord opgeslagen",
    "Conversation password has been removed" : "Gesprekswachtwoord  verwijderd",
    "Error occurred while saving conversation password" : "Er trad een fout op bij het opslaan van het gesprekswachtwoord ",
    "Could not post message: {errorMessage}" : "Kon bericht niet plaatsen: {errorMessage}",
    "An error occurred while fetching the participants" : "Er trad een fout op bij het ophalen van de deelnemers",
    "Could not send invitation to {actorId}" : "Kon uitnodiging niet versturen naar {actorId}",
    "Invitations sent" : "Uitnodigingen verzonden",
    "Error occurred when sending invitations" : "Er trad een fout op bij het verzenden van uitnodigingen",
    "{guest} (guest)" : "{guest} (gast)",
    "Failed to add reaction" : "Reactie toevoegen mislukt",
    "Failed to remove reaction" : "Reactie verwijderen mislukt",
    "The server is in maintenance mode." : "De server staat in onderhoudsmodus.",
    "Federated server was updated." : "Gefedereerde server heeft een update gehad.",
    "Error while uploading file \"{fileName}\"" : "Fout bij opslaan bestand \"{fileName}\".",
    "Not enough free space to upload file \"{fileName}\"" : "Onvoldoende vrije ruimte om \"{fileName}\" op te slaan",
    "You are not allowed to share files" : "Je bent niet geautoriseerd om bestanden te delen",
    "Error while sharing file" : "Fout bij delen bestand",
    "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "De browser die je gebruikt, wordt niet volledig ondersteund door Nextcloud Talk. Gebruik alsjeblieft de laatste versie van Mozilla Firefox, Microsoft Edge, Google Chrome, Opera of Apple Safari.",
    "_%n minute _::_%n minutes_" : ["%n minuten","%n minuten"],
    "In {hours} and {minutes}" : "In {hours} en {minutes}",
    "_In %n minute_::_In %n minutes_" : ["Over %n minuten","Over %n minuten"],
    "Later today – {timeLocale}" : "Later vandaag – {timeLocale}",
    "Tomorrow – {timeLocale}" : "Morgen - {timeLocale}",
    "This weekend – {timeLocale}" : "Dit weekend - {timeLocale}",
    "Next week – {timeLocale}" : "Volgende week - {timeLocale}",
    "Message link copied to clipboard" : "Bericht-link naar klembord gekopieerd",
    "Conversation link copied to clipboard" : "Gespreks-link naar klembord gekopieerd",
    "The link could not be copied" : "De link kon niet gekopieerd worden",
    "Error while parsing a PROPFIND error" : "Fout tijdens het analyseren van een PROPFIND fout",
    "Lost connection to signaling server. Trying to reconnect." : "Verbinding met signaleringsserver verbroken. Ik probeer opnieuw verbinding te maken.",
    "Please reload the page." : "Herlaad deze pagina.",
    "Do not disturb" : "Niet storen",
    "Away" : "Afwezig",
    "Microphone {number}" : "Microfoon {number}",
    "Camera {number}" : "Camera {number}",
    "Speaker {number}" : "Speaker {number}",
    "You seem to be talking while muted, please unmute yourself for others to hear you" : "Je lijkt te spreken terwijl je gedempt bent. Haal de demping weg zodat anderen je ook horen",
    "Could not establish a connection with at least one participant. A TURN server might be needed for your scenario. Please ask your administrator to set one up following {linkstart}this documentation{linkend}." : "Kon geen verbinding maken met ten minste één deelnemer. Een TURN server kan nodig zijn. Neem contact op met je beheerder om er eentje te laten inrichten volgende {linkstart}deze instructies{linkend}.",
    "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "Dit duurt langer dan verwacht. Zijn de mediamachtigingen al verstrekt (of geweigerd)? Zo ja, herstart dan je browser, omdat audio en video niet lukken",
    "Access to microphone & camera is only possible with HTTPS" : "Toegang tot microfoon & camera is alleen mogelijk met HTTPS",
    "Please move your setup to HTTPS" : "Stel de verbinding als HTTPS in",
    "Access to microphone & camera was denied" : "Toegang tot microfoon & camera geweigerd",
    "WebRTC is not supported in your browser" : "WebRTC wordt niet ondersteund door je browser",
    "Please use a different browser like Firefox or Chrome" : "Gebruik een andere browser, zoals Firefox of Chrome",
    "Error while accessing microphone & camera" : "Fout bij benaderen microfoon & camera",
    "%s Talk on your mobile devices" : "%s Talk op je mobiele apparaten",
    "Join conversations at any time, anywhere, on any device." : "Doe mee met gesprekken op elk tijdstip, overal met elk apparaat.",
    "Android app" : "Android app",
    "iOS app" : "iOS app",
    "__language_name__" : "Nederlands",
    "Call summary (%s)" : "Gesprekssamenvatting (%s)",
    "The call summary bot posts an overview message after the call listing all participants and outlining tasks" : "De bot gespekssamenvatting plaatst na de oproep een overzichtsbericht waarin alle deelnemers worden vermeld en taken worden beschreven",
    "Tasks" : "Taken",
    "Notes" : "Notities",
    "Reports" : "Rapporten",
    "Decisions" : "Besluiten",
    "Agenda" : "Agenda",
    "Call summary" : "Gesprekssamenvatting",
    "Call summary - {title}" : "Gesprekssamenvatting - {title}",
    "Talk conversation for event" : "Talk gesprek voor gebeurtenis",
    "Next meeting" : "Volgende vergadering",
    "Schedule a meeting from your calendar. A Talk conversation needs to be set as location to show up here" : "Plan een vergadering vanuit je agenda. Een Talk conversatie moet worden ingesteld als locatie om hier te verschijnen",
    "Join conversations from remote Nextcloud servers" : "Neem deel aan gesprekken van andere Netxcloud servers",
    "Set reminder for later today" : "Herinnering instellen voor later vandaag ",
    "Set reminder for tomorrow" : "Herinnering instellen voor morgen ",
    "Set reminder for this weekend" : "Herinnering instellen voor het weekend ",
    "Set reminder for next week" : "Herinnering instellen voor volgende week",
    "Generate summary" : "Maak samenvatting",
    "Talk recording from {time} ({conversation})" : "Talk opnam van {time} ({conversation})",
    "Your privacy setting has been saved" : "Je privacy-instellingen zijn opgeslagen",
    "Failed to save sounds setting" : "Kon geluidsinstellingen niet opslaan",
    "Sounds setting saved" : "Geluidsinstellingen opgeslagen",
    "You joined the conversation in another window or device. This is currently not supported by Nextcloud Talk so this session was closed." : "Je nam deel aan het gesprek in een ander venster of apparaat. Dit wordt momenteel niet ondersteund door Nextcloud Talk, dus deze sessie is gesloten."
},
"nplurals=2; plural=(n != 1);");
